import * as React from 'react';
import type { BaseUIComponentProps } from '../../utils/types';
import type { TransitionStatus } from '../../utils/useTransitionStatus';
/**
 *
 * Demos:
 *
 * - [Alert Dialog](https://base-ui.netlify.app/components/react-alert-dialog/)
 *
 * API:
 *
 * - [AlertDialogPopup API](https://base-ui.netlify.app/components/react-alert-dialog/#api-reference-AlertDialogPopup)
 */
declare const AlertDialogPopup: React.ForwardRefExoticComponent<AlertDialogPopup.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace AlertDialogPopup {
    interface Props extends BaseUIComponentProps<'div', OwnerState> {
        /**
         * The container element to which the popup is appended to.
         */
        container?: HTMLElement | null | React.MutableRefObject<HTMLElement | null>;
        /**
         * If `true`, the dialog element is kept in the DOM when closed.
         *
         * @default false
         */
        keepMounted?: boolean;
    }
    interface OwnerState {
        open: boolean;
        nestedOpenDialogCount: number;
        transitionStatus: TransitionStatus;
    }
}
export { AlertDialogPopup };
