'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { FloatingFocusManager, FloatingPortal } from '@floating-ui/react';
import { useDialogPopup } from '../../Dialog/Popup/useDialogPopup';
import { useAlertDialogRootContext } from '../Root/AlertDialogRootContext';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
import { refType, HTMLElementType } from '../../utils/proptypes';
import { jsx as _jsx } from "react/jsx-runtime";
/**
 *
 * Demos:
 *
 * - [Alert Dialog](https://base-ui.netlify.app/components/react-alert-dialog/)
 *
 * API:
 *
 * - [AlertDialogPopup API](https://base-ui.netlify.app/components/react-alert-dialog/#api-reference-AlertDialogPopup)
 */
const AlertDialogPopup = /*#__PURE__*/React.forwardRef(function AlertDialogPopup(props, forwardedRef) {
  const {
    className,
    container,
    id,
    keepMounted = false,
    render,
    ...other
  } = props;
  const rootContext = useAlertDialogRootContext();
  const {
    open,
    nestedOpenDialogCount
  } = rootContext;
  const {
    getRootProps,
    floatingContext,
    mounted,
    transitionStatus
  } = useDialogPopup({
    id,
    ref: forwardedRef,
    dismissible: false,
    isTopmost: nestedOpenDialogCount === 0,
    ...rootContext
  });
  const ownerState = {
    open,
    nestedOpenDialogCount,
    transitionStatus
  };
  const {
    renderElement
  } = useComponentRenderer({
    render: render ?? 'div',
    className,
    ownerState,
    propGetter: getRootProps,
    extraProps: {
      ...other,
      style: {
        ...other.style,
        '--nested-dialogs': nestedOpenDialogCount
      },
      role: 'alertdialog'
    },
    customStyleHookMapping: {
      open: value => ({
        'data-state': value ? 'open' : 'closed'
      }),
      nestedOpenDialogCount: value => ({
        'data-nested-dialogs': value.toString()
      }),
      transitionStatus: value => {
        if (value === 'entering') {
          return {
            'data-entering': ''
          };
        }
        if (value === 'exiting') {
          return {
            'data-exiting': ''
          };
        }
        return null;
      }
    }
  });
  if (!keepMounted && !mounted) {
    return null;
  }
  return /*#__PURE__*/_jsx(FloatingPortal, {
    root: container,
    children: /*#__PURE__*/_jsx(FloatingFocusManager, {
      context: floatingContext,
      modal: true,
      disabled: !mounted,
      children: renderElement()
    })
  });
});
process.env.NODE_ENV !== "production" ? AlertDialogPopup.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * The container element to which the popup is appended to.
   */
  container: PropTypes /* @typescript-to-proptypes-ignore */.oneOfType([HTMLElementType, refType]),
  /**
   * @ignore
   */
  id: PropTypes.string,
  /**
   * If `true`, the dialog element is kept in the DOM when closed.
   *
   * @default false
   */
  keepMounted: PropTypes.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func]),
  /**
   * @ignore
   */
  style: PropTypes.object
} : void 0;
export { AlertDialogPopup };