'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { useAlertDialogRootContext } from '../Root/AlertDialogRootContext';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
import { useEnhancedEffect } from '../../utils/useEnhancedEffect';
import { useId } from '../../utils/useId';
/**
 *
 * Demos:
 *
 * - [Alert Dialog](https://base-ui.netlify.app/components/react-alert-dialog/)
 *
 * API:
 *
 * - [AlertDialogTitle API](https://base-ui.netlify.app/components/react-alert-dialog/#api-reference-AlertDialogTitle)
 */
const AlertDialogTitle = /*#__PURE__*/React.forwardRef(function AlertDialogTitle(props, forwardedRef) {
  const {
    render,
    className,
    id: idProp,
    ...other
  } = props;
  const {
    setTitleElementId,
    open
  } = useAlertDialogRootContext();
  const ownerState = {
    open
  };
  const id = useId(idProp);
  useEnhancedEffect(() => {
    setTitleElementId(id);
    return () => {
      setTitleElementId(undefined);
    };
  }, [id, setTitleElementId]);
  const {
    renderElement
  } = useComponentRenderer({
    render: render ?? 'h2',
    className,
    ownerState,
    ref: forwardedRef,
    extraProps: other
  });
  return renderElement();
});
process.env.NODE_ENV !== "production" ? AlertDialogTitle.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * @ignore
   */
  id: PropTypes.string,
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func])
} : void 0;
export { AlertDialogTitle };