'use client';

import * as React from 'react';
import { useId } from '../../utils/useId';
import { useEventCallback } from '../../utils/useEventCallback';

/**
 *
 * API:
 *
 * - [useCheckboxGroupParent API](https://mui.com/base-ui/api/use-checkbox-group-parent/)
 */
export function useCheckboxGroupParent(params) {
  const {
    allValues = [],
    value = [],
    onValueChange: onValueChangeProp = () => {},
    preserveChildStates = false
  } = params;
  const uncontrolledStateRef = React.useRef(value);
  const [status, setStatus] = React.useState('mixed');
  const id = useId();
  const checked = value.length === allValues.length;
  const indeterminate = value.length !== allValues.length && value.length > 0;
  const onValueChange = useEventCallback(onValueChangeProp);
  const getParentProps = React.useCallback(() => ({
    id,
    indeterminate,
    checked,
    'aria-controls': allValues.map(v => `${id}-${v}`).join(' '),
    onCheckedChange(_, event) {
      const uncontrolledState = uncontrolledStateRef.current;
      const allOnOrOff = uncontrolledState.length === allValues.length || uncontrolledState.length === 0;
      if (allOnOrOff) {
        if (value.length === allValues.length) {
          onValueChange([], event);
        } else {
          onValueChange(allValues, event);
        }
        return;
      }
      if (preserveChildStates) {
        if (status === 'mixed') {
          onValueChange(allValues, event);
          setStatus('on');
        } else if (status === 'on') {
          onValueChange([], event);
          setStatus('off');
        } else if (status === 'off') {
          onValueChange(uncontrolledState, event);
          setStatus('mixed');
        }
      } else if (checked) {
        onValueChange([], event);
        setStatus('off');
      } else {
        onValueChange(allValues, event);
        setStatus('on');
      }
    }
  }), [allValues, checked, id, indeterminate, onValueChange, preserveChildStates, status, value.length]);
  const getChildProps = React.useCallback(name => ({
    name,
    id: `${id}-${name}`,
    checked: value.includes(name),
    onCheckedChange(nextChecked, event) {
      const newValue = [...value];
      if (nextChecked) {
        newValue.push(name);
      } else {
        newValue.splice(newValue.indexOf(name), 1);
      }
      uncontrolledStateRef.current = newValue;
      onValueChange(newValue, event);
      setStatus('mixed');
    }
  }), [id, onValueChange, value]);
  return React.useMemo(() => ({
    id,
    indeterminate,
    getParentProps,
    getChildProps
  }), [id, indeterminate, getParentProps, getChildProps]);
}
export let UseCheckboxGroupParent;