import * as React from 'react';
import type { BaseUIComponentProps } from '../../utils/types';
import type { FieldRootOwnerState } from '../../Field/Root/FieldRoot.types';
/**
 * The foundation for building custom-styled checkbox groups.
 *
 * Demos:
 *
 * - [Checkbox Group](https://base-ui.netlify.app/components/react-checkbox-group/)
 *
 * API:
 *
 * - [CheckboxGroupRoot API](https://base-ui.netlify.app/components/react-checkbox-group/#api-reference-CheckboxGroupRoot)
 */
declare const CheckboxGroupRoot: React.ForwardRefExoticComponent<CheckboxGroupRoot.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace CheckboxGroupRoot {
    interface OwnerState extends FieldRootOwnerState {
        disabled: boolean;
    }
    interface Props extends BaseUIComponentProps<'div', OwnerState> {
        /**
         * The currently checked values of the checkbox group. Use when controlled.
         */
        value?: string[];
        /**
         * The default checked values of the checkbox group. Use when uncontrolled.
         */
        defaultValue?: string[];
        /**
         * A callback function that is called when the value of the checkbox group changes.
         * Use when controlled.
         */
        onValueChange?: (value: string[], event: Event) => void;
        /**
         * All values of the checkboxes in the group.
         */
        allValues?: string[];
        /**
         * Whether the checkbox group is disabled.
         * @default false
         */
        disabled?: boolean;
        /**
         * Whether the parent checkbox should preserve its child states when checked/unchecked, leading
         * to a tri-state checkbox group.
         * @default false
         */
        preserveChildStates?: boolean;
    }
}
export { CheckboxGroupRoot };
