'use client';

import * as React from 'react';
import { mergeReactProps } from '../../utils/mergeReactProps';
import { useControlled } from '../../utils/useControlled';
import { useEventCallback } from '../../utils/useEventCallback';
import { useCheckboxGroupParent } from '../Parent/useCheckboxGroupParent';
import { useFieldRootContext } from '../../Field/Root/FieldRootContext';
/**
 *
 * API:
 *
 * - [useCheckboxGroupRoot API](https://mui.com/base-ui/api/use-checkbox-group-root/)
 */
export function useCheckboxGroupRoot(params) {
  const {
    allValues,
    value: externalValue,
    defaultValue,
    onValueChange,
    preserveChildStates
  } = params;
  const {
    labelId
  } = useFieldRootContext();
  const [value, setValueUnwrapped] = useControlled({
    controlled: externalValue,
    default: defaultValue,
    name: 'CheckboxGroup',
    state: 'value'
  });
  const setValue = useEventCallback((v, event) => {
    setValueUnwrapped(v);
    onValueChange?.(v, event);
  });
  const parent = useCheckboxGroupParent({
    allValues,
    value: externalValue,
    onValueChange,
    preserveChildStates
  });
  const getRootProps = React.useCallback((externalProps = {}) => mergeReactProps(externalProps, {
    role: 'group',
    'aria-labelledby': labelId
  }), [labelId]);
  return React.useMemo(() => ({
    getRootProps,
    value,
    setValue,
    parent
  }), [getRootProps, value, setValue, parent]);
}