import * as React from 'react';
import { TransitionStatus } from '../../utils/useTransitionStatus';
export declare function useCollapsibleRoot(parameters: useCollapsibleRoot.Parameters): useCollapsibleRoot.ReturnValue;
export declare namespace useCollapsibleRoot {
    interface Parameters {
        /**
         * If `true`, the component supports CSS/JS-based animations and transitions.
         * @default true
         */
        animated?: boolean;
        /**
         * If `true`, the Collapsible is initially open.
         * This is the controlled counterpart of `defaultOpen`.
         */
        open?: boolean;
        /**
         * If `true`, the Collapsible is initially open.
         * This is the uncontrolled counterpart of `open`.
         * @default true
         */
        defaultOpen?: boolean;
        /**
         * Callback fired when the Collapsible is opened or closed.
         */
        onOpenChange?: (open: boolean) => void;
        /**
         * If `true`, the component is disabled.
         * @default false
         */
        disabled?: boolean;
    }
    interface ReturnValue {
        animated: boolean;
        contentId: React.HTMLAttributes<Element>['id'];
        /**
         * The disabled state of the Collapsible
         */
        disabled: boolean;
        mounted: boolean;
        /**
         * The open state of the Collapsible
         */
        open: boolean;
        setContentId: (id: string | undefined) => void;
        setMounted: (open: boolean) => void;
        setOpen: (open: boolean) => void;
        transitionStatus: TransitionStatus;
    }
}
