'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
import { CompositeList } from '../List/CompositeList';
import { useCompositeRoot } from './useCompositeRoot';
import { CompositeRootContext } from './CompositeRootContext';
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * @ignore - internal component.
 */
const CompositeRoot = /*#__PURE__*/React.forwardRef(function CompositeRoot(props, forwardedRef) {
  const {
    render,
    className,
    activeIndex: activeIndexProp,
    onActiveIndexChange: onActiveIndexChangeProp,
    orientation,
    dense,
    itemSizes,
    loop,
    cols,
    ...otherProps
  } = props;
  const {
    getRootProps,
    activeIndex,
    onActiveIndexChange,
    elementsRef
  } = useCompositeRoot(props);
  const {
    renderElement
  } = useComponentRenderer({
    propGetter: getRootProps,
    ref: forwardedRef,
    render: render ?? 'div',
    ownerState: {},
    className,
    extraProps: otherProps
  });
  const contextValue = React.useMemo(() => ({
    activeIndex,
    onActiveIndexChange
  }), [activeIndex, onActiveIndexChange]);
  return /*#__PURE__*/_jsx(CompositeRootContext.Provider, {
    value: contextValue,
    children: /*#__PURE__*/_jsx(CompositeList, {
      elementsRef: elementsRef,
      children: renderElement()
    })
  });
});
process.env.NODE_ENV !== "production" ? CompositeRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  activeIndex: PropTypes.number,
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * @ignore
   */
  cols: PropTypes.number,
  /**
   * @ignore
   */
  dense: PropTypes.bool,
  /**
   * @ignore
   */
  itemSizes: PropTypes.arrayOf(PropTypes.shape({
    height: PropTypes.number.isRequired,
    width: PropTypes.number.isRequired
  })),
  /**
   * @ignore
   */
  loop: PropTypes.bool,
  /**
   * @ignore
   */
  onActiveIndexChange: PropTypes.func,
  /**
   * @ignore
   */
  orientation: PropTypes.oneOf(['both', 'horizontal', 'vertical']),
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func])
} : void 0;
export { CompositeRoot };