import * as React from 'react';
import { type TransitionStatus } from '../../utils/useTransitionStatus';
export declare function useDialogBackdrop(params: useDialogBackdrop.Parameters): useDialogBackdrop.ReturnValue;
export declare namespace useDialogBackdrop {
    interface Parameters {
        /**
         * If `true`, the dialog supports CSS-based animations and transitions.
         * It is kept in the DOM until the animation completes.
         */
        animated: boolean;
        /**
         * Determines if the dialog is open.
         */
        open: boolean;
        /**
         * The ref to the background element.
         */
        ref: React.Ref<HTMLElement>;
        /**
         * Callback to invoke when the backdrop is mounted.
         */
        onMount: () => void;
        /**
         * Callback to invoke when the backdrop is unmounted.
         */
        onUnmount: () => void;
    }
    interface ReturnValue {
        /**
         * Resolver for the root element props.
         */
        getRootProps: (externalProps?: Record<string, any>) => Record<string, any>;
        /**
         * Determines if the dialog should be mounted even if closed (as the exit animation is still in progress).
         */
        mounted: boolean;
        /**
         * The current transition status of the dialog.
         */
        transitionStatus: TransitionStatus;
    }
}
