'use client';

import * as React from 'react';
import { mergeReactProps } from '../../utils/mergeReactProps';
import { useAnimatedElement } from '../../utils/useAnimatedElement';
import { useForkRef } from '../../utils/useForkRef';
import { useEventCallback } from '../../utils/useEventCallback';
import { useEnhancedEffect } from '../../utils/useEnhancedEffect';
export function useDialogBackdrop(params) {
  const {
    animated,
    open,
    ref,
    onMount: onMountParam,
    onUnmount: onUnmountParam
  } = params;
  const backdropRef = React.useRef(null);
  const handleRef = useForkRef(ref, backdropRef);
  const {
    mounted,
    transitionStatus
  } = useAnimatedElement({
    open,
    ref: backdropRef,
    enabled: animated
  });
  const onMount = useEventCallback(onMountParam);
  const onUnmount = useEventCallback(onUnmountParam);
  useEnhancedEffect(() => {
    onMount();
    return onUnmount;
  }, [onMount, onUnmount]);
  const getRootProps = React.useCallback(externalProps => mergeReactProps(externalProps, {
    role: 'presentation',
    ref: handleRef
  }), [handleRef]);
  return {
    getRootProps,
    mounted,
    transitionStatus
  };
}