'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { useDialogClose } from './useDialogClose';
import { useDialogRootContext } from '../Root/DialogRootContext';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
/**
 *
 * Demos:
 *
 * - [Dialog](https://base-ui.netlify.app/components/react-dialog/)
 *
 * API:
 *
 * - [DialogClose API](https://base-ui.netlify.app/components/react-dialog/#api-reference-DialogClose)
 */
const DialogClose = /*#__PURE__*/React.forwardRef(function DialogClose(props, forwardedRef) {
  const {
    render,
    className,
    ...other
  } = props;
  const {
    open,
    onOpenChange,
    modal
  } = useDialogRootContext();
  const {
    getRootProps
  } = useDialogClose({
    open,
    onOpenChange
  });
  const ownerState = {
    open,
    modal
  };
  const {
    renderElement
  } = useComponentRenderer({
    render: render ?? 'button',
    className,
    ownerState,
    propGetter: getRootProps,
    ref: forwardedRef,
    extraProps: other
  });
  return renderElement();
});
process.env.NODE_ENV !== "production" ? DialogClose.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func])
} : void 0;
export { DialogClose };