import * as React from 'react';
import { type BaseUIComponentProps } from '../../utils/types';
import { type TransitionStatus } from '../../utils/useTransitionStatus';
/**
 *
 * Demos:
 *
 * - [Dialog](https://base-ui.netlify.app/components/react-dialog/)
 *
 * API:
 *
 * - [DialogPopup API](https://base-ui.netlify.app/components/react-dialog/#api-reference-DialogPopup)
 */
declare const DialogPopup: React.ForwardRefExoticComponent<DialogPopup.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace DialogPopup {
    interface Props extends BaseUIComponentProps<'div', OwnerState> {
        /**
         * The container element to which the popup is appended to.
         */
        container?: HTMLElement | null | React.MutableRefObject<HTMLElement | null>;
        /**
         * If `true`, the dialog element is kept in the DOM when closed.
         *
         * @default false
         */
        keepMounted?: boolean;
    }
    interface OwnerState {
        open: boolean;
        modal: boolean;
        nestedOpenDialogCount: number;
        transitionStatus: TransitionStatus;
    }
}
export { DialogPopup };
