'use client';

import * as React from 'react';
import { useControlled } from '../../utils/useControlled';
export function useDialogRoot(parameters) {
  const {
    open: openParam,
    defaultOpen = false,
    onOpenChange,
    modal = true,
    onNestedDialogOpen,
    onNestedDialogClose
  } = parameters;
  const [open, setOpen] = useControlled({
    controlled: openParam,
    default: defaultOpen,
    name: 'DialogRoot'
  });
  const [titleElementId, setTitleElementId] = React.useState(undefined);
  const [descriptionElementId, setDescriptionElementId] = React.useState(undefined);
  const [popupElementId, setPopupElementId] = React.useState(undefined);
  const hasBackdrop = React.useRef(false);
  if (process.env.NODE_ENV !== 'production') {
    // eslint-disable-next-line react-hooks/rules-of-hooks
    React.useEffect(() => {
      if (modal && !hasBackdrop.current) {
        console.warn('Base UI: The Dialog is modal but no backdrop is present. Add the backdrop component to prevent interacting with the rest of the page.');
      }
    }, [modal]);
  }
  const handleOpenChange = React.useCallback(shouldOpen => {
    setOpen(shouldOpen);
    onOpenChange?.(shouldOpen);
  }, [onOpenChange, setOpen]);
  const [ownNestedOpenDialogs, setOwnNestedOpenDialogs] = React.useState(0);
  React.useEffect(() => {
    if (onNestedDialogOpen && open) {
      onNestedDialogOpen(ownNestedOpenDialogs);
    }
    if (onNestedDialogClose && !open) {
      onNestedDialogClose();
    }
    return () => {
      if (onNestedDialogClose && open) {
        onNestedDialogClose();
      }
      if (onNestedDialogOpen && !open) {
        onNestedDialogOpen(ownNestedOpenDialogs);
      }
    };
  }, [open, onNestedDialogClose, onNestedDialogOpen, ownNestedOpenDialogs]);
  const handleNestedDialogOpen = React.useCallback(ownChildrenCount => {
    setOwnNestedOpenDialogs(ownChildrenCount + 1);
  }, []);
  const handleNestedDialogClose = React.useCallback(() => {
    setOwnNestedOpenDialogs(0);
  }, []);
  const setBackdropPresent = React.useCallback(present => {
    hasBackdrop.current = present;
  }, []);
  return React.useMemo(() => {
    return {
      modal,
      onOpenChange: handleOpenChange,
      open,
      titleElementId,
      setTitleElementId,
      descriptionElementId,
      setDescriptionElementId,
      popupElementId,
      setPopupElementId,
      onNestedDialogOpen: handleNestedDialogOpen,
      onNestedDialogClose: handleNestedDialogClose,
      nestedOpenDialogCount: ownNestedOpenDialogs,
      setBackdropPresent
    };
  }, [modal, handleOpenChange, open, titleElementId, descriptionElementId, popupElementId, handleNestedDialogClose, handleNestedDialogOpen, ownNestedOpenDialogs, setBackdropPresent]);
}