'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { useFieldRootContext } from '../Root/FieldRootContext';
import { getCombinedFieldValidityData } from '../utils/getCombinedFieldValidityData';

/**
 * Render prop component that provides the field's validity state and value to its children.
 *
 * Demos:
 *
 * - [Field](https://base-ui.netlify.app/components/react-field/)
 *
 * API:
 *
 * - [FieldValidity API](https://base-ui.netlify.app/components/react-field/#api-reference-FieldValidity)
 */
import { jsx as _jsx } from "react/jsx-runtime";
function FieldValidity(props) {
  const {
    validityData,
    invalid
  } = useFieldRootContext(false);
  const fieldValidityState = React.useMemo(() => {
    const combinedFieldValidityData = getCombinedFieldValidityData(validityData, invalid);
    return {
      ...combinedFieldValidityData,
      validity: combinedFieldValidityData.state
    };
  }, [validityData, invalid]);
  return /*#__PURE__*/_jsx(React.Fragment, {
    children: props.children(fieldValidityState)
  });
}
process.env.NODE_ENV !== "production" ? FieldValidity.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.func.isRequired
} : void 0;
export { FieldValidity };