import * as React from 'react';
import type { Side, Alignment } from '../../utils/useAnchorPositioning';
import type { BaseUIComponentProps } from '../../utils/types';
/**
 * Renders an arrow that points to the center of the anchor element.
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuArrow API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuArrow)
 */
declare const MenuArrow: React.ForwardRefExoticComponent<MenuArrow.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace MenuArrow {
    type OwnerState = {
        open: boolean;
        side: Side;
        alignment: Alignment;
        arrowUncentered: boolean;
    };
    interface Props extends BaseUIComponentProps<'div', OwnerState> {
        /**
         * If `true`, the arrow is hidden when it can't point to the center of the anchor element.
         * @default false
         */
        hideWhenUncentered?: boolean;
    }
}
export { MenuArrow };
