import * as React from 'react';
import type { BaseUIComponentProps } from '../../utils/types';
/**
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuCheckboxItem API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuCheckboxItem)
 */
declare const MenuCheckboxItem: React.ForwardRefExoticComponent<MenuCheckboxItem.Props & React.RefAttributes<Element>>;
declare namespace MenuCheckboxItem {
    type OwnerState = {
        disabled: boolean;
        highlighted: boolean;
        checked: boolean;
    };
    interface Props extends BaseUIComponentProps<'div', OwnerState> {
        checked?: boolean;
        defaultChecked?: boolean;
        onCheckedChange?: (checked: boolean, event: Event) => void;
        children?: React.ReactNode;
        /**
         * The click handler for the menu item.
         */
        onClick?: React.MouseEventHandler<HTMLElement>;
        /**
         * If `true`, the menu item will be disabled.
         * @default false
         */
        disabled?: boolean;
        /**
         * A text representation of the menu item's content.
         * Used for keyboard text navigation matching.
         */
        label?: string;
        /**
         * The id of the menu item.
         */
        id?: string;
        /**
         * If `true`, the menu will close when the menu item is clicked.
         *
         * @default true
         */
        closeOnClick?: boolean;
    }
}
export { MenuCheckboxItem };
