'use client';

import * as React from 'react';
import { useButton } from '../../useButton';
import { mergeReactProps } from '../../utils/mergeReactProps';
export function useMenuItem(params) {
  const {
    closeOnClick,
    disabled = false,
    highlighted,
    id,
    menuEvents,
    ref: externalRef,
    treatMouseupAsClick,
    typingRef
  } = params;
  const {
    getButtonProps,
    buttonRef: mergedRef
  } = useButton({
    disabled,
    focusableWhenDisabled: true,
    buttonRef: externalRef
  });
  const getRootProps = React.useCallback(externalProps => {
    return getButtonProps(mergeReactProps(externalProps, {
      'data-handle-mouseup': treatMouseupAsClick || undefined,
      id,
      role: 'menuitem',
      tabIndex: highlighted ? 0 : -1,
      onKeyUp: event => {
        if (event.key === ' ' && typingRef.current) {
          event.defaultMuiPrevented = true;
        }
      },
      onClick: event => {
        if (event.type === 'keydown') {
          if (event.key === 'Enter') {
            menuEvents.emit('close', event);
            return;
          }
        }
        if (closeOnClick) {
          menuEvents.emit('close', event);
        }
      }
    }));
  }, [closeOnClick, getButtonProps, highlighted, id, menuEvents, treatMouseupAsClick, typingRef]);
  return React.useMemo(() => ({
    getRootProps,
    rootRef: mergedRef
  }), [getRootProps, mergedRef]);
}