'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { useFloatingTree } from '@floating-ui/react';
import { useMenuPopup } from './useMenuPopup';
import { useMenuRootContext } from '../Root/MenuRootContext';
import { useMenuPositionerContext } from '../Positioner/MenuPositionerContext';
import { commonStyleHooks } from '../utils/commonStyleHooks';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
import { useForkRef } from '../../utils/useForkRef';
const customStyleHookMapping = {
  ...commonStyleHooks,
  entering(value) {
    return value ? {
      'data-menu-entering': ''
    } : null;
  },
  exiting(value) {
    return value ? {
      'data-menu-exiting': ''
    } : null;
  }
};

/**
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuPopup API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuPopup)
 */
const MenuPopup = /*#__PURE__*/React.forwardRef(function MenuPopup(props, forwardedRef) {
  const {
    render,
    className,
    ...other
  } = props;
  const {
    open,
    setOpen,
    popupRef,
    transitionStatus
  } = useMenuRootContext();
  const {
    side,
    alignment
  } = useMenuPositionerContext();
  const {
    events: menuEvents
  } = useFloatingTree();
  useMenuPopup({
    setOpen,
    menuEvents
  });
  const mergedRef = useForkRef(forwardedRef, popupRef);
  const ownerState = {
    entering: transitionStatus === 'entering',
    exiting: transitionStatus === 'exiting',
    side,
    alignment,
    open
  };
  const {
    renderElement
  } = useComponentRenderer({
    render: render || 'div',
    className,
    ownerState,
    extraProps: other,
    customStyleHookMapping,
    ref: mergedRef
  });
  return renderElement();
});
process.env.NODE_ENV !== "production" ? MenuPopup.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * The id of the popup element.
   */
  id: PropTypes.string,
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func])
} : void 0;
export { MenuPopup };