'use client';

import * as React from 'react';
import { mergeReactProps } from '../../utils/mergeReactProps';
import { useAnchorPositioning } from '../../utils/useAnchorPositioning';
import { getInertValue } from '../../utils/getInertValue';
export function useMenuPositioner(params) {
  const {
    open = false,
    keepMounted
  } = params;
  const {
    positionerStyles,
    arrowStyles,
    hidden,
    arrowRef,
    arrowUncentered,
    renderedSide,
    renderedAlignment,
    positionerContext: floatingContext
  } = useAnchorPositioning(params);
  const getPositionerProps = React.useCallback((externalProps = {}) => {
    const hiddenStyles = {};
    if (keepMounted && !open || hidden) {
      hiddenStyles.pointerEvents = 'none';
    }
    return mergeReactProps(externalProps, {
      style: {
        ...positionerStyles,
        ...hiddenStyles,
        zIndex: 2147483647 // max z-index
      },
      'aria-hidden': !open || undefined,
      inert: getInertValue(!open)
    });
  }, [positionerStyles, open, keepMounted, hidden]);
  return React.useMemo(() => ({
    getPositionerProps,
    arrowRef,
    arrowUncentered,
    arrowStyles,
    side: renderedSide,
    alignment: renderedAlignment,
    floatingContext
  }), [getPositionerProps, arrowRef, arrowUncentered, arrowStyles, renderedSide, renderedAlignment, floatingContext]);
}