import * as React from 'react';
import type { BaseUIComponentProps } from '../../utils/types';
/**
 * An unstyled menu item to be used within a Menu.
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuRadioItem API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuRadioItem)
 */
declare const MenuRadioItem: React.ForwardRefExoticComponent<MenuRadioItem.Props & React.RefAttributes<Element>>;
declare namespace MenuRadioItem {
    type OwnerState = {
        disabled: boolean;
        highlighted: boolean;
        checked: boolean;
    };
    interface Props extends BaseUIComponentProps<'div', OwnerState> {
        /**
         * Value of the radio item.
         * This is the value that will be set in the MenuRadioGroup when the item is selected.
         */
        value: any;
        children?: React.ReactNode;
        /**
         * The click handler for the menu item.
         */
        onClick?: React.MouseEventHandler<HTMLElement>;
        /**
         * If `true`, the menu item will be disabled.
         * @default false
         */
        disabled?: boolean;
        /**
         * A text representation of the menu item's content.
         * Used for keyboard text navigation matching.
         */
        label?: string;
        /**
         * The id of the menu item.
         */
        id?: string;
        /**
         * If `true`, the menu will close when the menu item is clicked.
         *
         * @default true
         */
        closeOnClick?: boolean;
    }
}
export { MenuRadioItem };
