import * as React from 'react';
import { useMenuItem } from '../Item/useMenuItem';
import { mergeReactProps } from '../../utils/mergeReactProps';

/**
 *
 * API:
 *
 * - [useMenuRadioItem API](https://mui.com/base-ui/api/use-menu-radio-item/)
 */
export function useMenuRadioItem(params) {
  const {
    checked,
    setChecked,
    ...other
  } = params;
  const {
    getRootProps: getMenuItemRootProps,
    ...menuItem
  } = useMenuItem(other);
  const getRootProps = React.useCallback(externalProps => {
    return getMenuItemRootProps(mergeReactProps(externalProps, {
      role: 'menuitemradio',
      'aria-checked': checked,
      onClick: event => {
        setChecked(event.nativeEvent);
      }
    }));
  }, [checked, getMenuItemRootProps, setChecked]);
  return {
    ...menuItem,
    getRootProps,
    checked
  };
}