import * as React from 'react';
import PropTypes from 'prop-types';
import { useMenuRadioItemContext } from '../RadioItem/MenuRadioItemContext';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
const customStyleHookMapping = {
  checked: value => ({
    'data-radioitem': value ? 'checked' : 'unchecked'
  })
};

/**
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuRadioItemIndicator API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuRadioItemIndicator)
 */
const MenuRadioItemIndicator = /*#__PURE__*/React.forwardRef(function MenuRadioItemIndicatorComponent(props, forwardedRef) {
  const {
    render,
    className,
    keepMounted = true,
    ...other
  } = props;
  const ownerState = useMenuRadioItemContext();
  const {
    renderElement
  } = useComponentRenderer({
    render: render || 'span',
    className,
    ownerState,
    customStyleHookMapping,
    extraProps: other,
    ref: forwardedRef
  });
  if (!keepMounted && !ownerState.checked) {
    return null;
  }
  return renderElement();
});
process.env.NODE_ENV !== "production" ? MenuRadioItemIndicator.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * If `true`, the component is mounted even if the Radio is not checked.
   *
   * @default true
   */
  keepMounted: PropTypes.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func])
} : void 0;
export { MenuRadioItemIndicator };