'use client';

import * as React from 'react';
import { safePolygon, useClick, useDismiss, useFloatingRootContext, useHover, useInteractions, useListNavigation, useRole, useTypeahead } from '@floating-ui/react';
import { mergeReactProps } from '../../utils/mergeReactProps';
import { useTransitionStatus } from '../../utils/useTransitionStatus';
import { useEventCallback } from '../../utils/useEventCallback';
import { useAnimationsFinished } from '../../utils/useAnimationsFinished';
import { useControlled } from '../../utils/useControlled';
const EMPTY_ARRAY = [];
export function useMenuRoot(parameters) {
  const {
    animated,
    open: openParam,
    defaultOpen,
    onOpenChange,
    orientation,
    direction,
    disabled,
    nested,
    closeParentOnEsc,
    loop,
    delay,
    openOnHover,
    onTypingChange
  } = parameters;
  const [triggerElement, setTriggerElement] = React.useState(null);
  const [positionerElement, setPositionerElement] = React.useState(null);
  const popupRef = React.useRef(null);
  const [hoverEnabled, setHoverEnabled] = React.useState(true);
  const [activeIndex, setActiveIndex] = React.useState(null);
  const [open, setOpenUnwrapped] = useControlled({
    controlled: openParam,
    default: defaultOpen,
    name: 'useMenuRoot',
    state: 'open'
  });
  const {
    mounted,
    setMounted,
    transitionStatus
  } = useTransitionStatus(open, animated);
  const runOnceAnimationsFinish = useAnimationsFinished(popupRef);
  const setOpen = useEventCallback((nextOpen, event) => {
    onOpenChange?.(nextOpen, event);
    setOpenUnwrapped(nextOpen);
    if (!nextOpen) {
      if (animated) {
        runOnceAnimationsFinish(() => setMounted(false));
      } else {
        setMounted(false);
      }
    }
  });
  const floatingRootContext = useFloatingRootContext({
    elements: {
      reference: triggerElement,
      floating: positionerElement
    },
    open,
    onOpenChange: setOpen
  });
  const hover = useHover(floatingRootContext, {
    enabled: hoverEnabled && openOnHover && !disabled,
    handleClose: safePolygon({
      blockPointerEvents: true
    }),
    mouseOnly: true,
    delay: {
      open: delay
    }
  });
  const click = useClick(floatingRootContext, {
    enabled: !disabled,
    event: 'mousedown',
    toggle: !nested,
    ignoreMouse: nested
  });
  const dismiss = useDismiss(floatingRootContext, {
    bubbles: closeParentOnEsc
  });
  const role = useRole(floatingRootContext, {
    role: 'menu'
  });
  const itemDomElements = React.useRef([]);
  const itemLabels = React.useRef([]);
  const listNavigation = useListNavigation(floatingRootContext, {
    enabled: !disabled,
    listRef: itemDomElements,
    activeIndex,
    nested,
    loop,
    orientation,
    rtl: direction === 'rtl',
    disabledIndices: EMPTY_ARRAY,
    onNavigate: setActiveIndex
  });
  const typeahead = useTypeahead(floatingRootContext, {
    listRef: itemLabels,
    activeIndex,
    resetMs: 350,
    onMatch: index => {
      if (open && index !== activeIndex) {
        setActiveIndex(index);
      }
    },
    onTypingChange
  });
  const {
    getReferenceProps,
    getFloatingProps,
    getItemProps
  } = useInteractions([hover, click, dismiss, role, listNavigation, typeahead]);
  const getTriggerProps = React.useCallback(externalProps => getReferenceProps(mergeReactProps(externalProps, {
    onMouseEnter: () => {
      setHoverEnabled(true);
    }
  })), [getReferenceProps]);
  const getPositionerProps = React.useCallback(externalProps => getFloatingProps(mergeReactProps(externalProps, {
    onMouseEnter: () => {
      setHoverEnabled(false);
    }
  })), [getFloatingProps]);
  return React.useMemo(() => ({
    activeIndex,
    floatingRootContext,
    triggerElement,
    setTriggerElement,
    getTriggerProps,
    setPositionerElement,
    getPositionerProps,
    getItemProps,
    itemDomElements,
    itemLabels,
    mounted,
    transitionStatus,
    popupRef,
    open,
    setOpen
  }), [activeIndex, floatingRootContext, triggerElement, getTriggerProps, getPositionerProps, getItemProps, itemDomElements, itemLabels, mounted, transitionStatus, open, setOpen]);
}