import * as React from 'react';
import { FloatingEvents } from '@floating-ui/react';
import { GenericHTMLProps } from '../../utils/types';
export declare function useMenuTrigger(parameters: useMenuTrigger.Parameters): useMenuTrigger.ReturnValue;
export declare namespace useMenuTrigger {
    interface Parameters {
        /**
         * If `true`, the component is disabled.
         * @default false
         */
        disabled?: boolean;
        /**
         * The ref to the root element.
         */
        rootRef?: React.Ref<HTMLElement>;
        /**
         * A callback to set the trigger element whenever it's mounted.
         */
        setTriggerElement: (element: HTMLElement | null) => void;
        /**
         * If `true`, the Menu is open.
         */
        open: boolean;
        /**
         * A callback to set the open state of the Menu.
         */
        setOpen: (open: boolean, event: Event | undefined) => void;
        /**
         * The FloatingEvents instance of the menu's root.
         */
        menuEvents: FloatingEvents;
        /**
         * A callback to enable/disable click and drag functionality.
         */
        setClickAndDragEnabled: (enabled: boolean) => void;
    }
    interface ReturnValue {
        /**
         * Resolver for the root slot's props.
         * @param externalProps props for the root slot
         * @returns props that should be spread on the root slot
         */
        getRootProps: (externalProps?: GenericHTMLProps) => GenericHTMLProps;
        /**
         * The ref to the root element.
         */
        rootRef: React.RefCallback<Element> | null;
    }
}
