'use client';

import * as React from 'react';
import { unstable_useForkRef as useForkRef } from '@mui/utils';
import { useButton } from '../../useButton/useButton';
import { mergeReactProps } from '../../utils/mergeReactProps';
import { ownerDocument } from '../../utils/owner';
export function useMenuTrigger(parameters) {
  const {
    disabled = false,
    rootRef: externalRef,
    open,
    setOpen,
    setTriggerElement,
    setClickAndDragEnabled
  } = parameters;
  const triggerRef = React.useRef(null);
  const mergedRef = useForkRef(externalRef, triggerRef);
  const {
    getButtonProps,
    buttonRef
  } = useButton({
    disabled,
    focusableWhenDisabled: false,
    buttonRef: mergedRef
  });
  const handleRef = useForkRef(buttonRef, setTriggerElement);
  const ignoreNextClick = React.useRef(false);
  const getRootProps = React.useCallback(externalProps => {
    return mergeReactProps(externalProps, {
      'aria-haspopup': 'menu',
      tabIndex: 0,
      // this is needed to make the button focused after click in Safari
      ref: handleRef,
      onMouseDown: event => {
        if (open) {
          return;
        }

        // prevents closing the menu right after it was opened
        ignoreNextClick.current = true;
        event.preventDefault();
        setClickAndDragEnabled(true);
        const mousedownTarget = event.target;
        function handleDocumentMouseUp(mouseUpEvent) {
          const mouseupTarget = mouseUpEvent.target;
          if (mouseupTarget?.dataset?.handleMouseup === 'true') {
            mouseupTarget.click();
          } else if (mouseupTarget !== triggerRef.current && !triggerRef.current?.contains(mouseupTarget)) {
            setOpen(false, mouseUpEvent);
          }
          setClickAndDragEnabled(false);
          ownerDocument(mousedownTarget).removeEventListener('mouseup', handleDocumentMouseUp);
        }
        ownerDocument(mousedownTarget).addEventListener('mouseup', handleDocumentMouseUp);
      },
      onClick: () => {
        if (ignoreNextClick.current) {
          ignoreNextClick.current = false;
        }
      }
    }, getButtonProps());
  }, [getButtonProps, handleRef, open, setOpen, setClickAndDragEnabled]);
  return React.useMemo(() => ({
    getRootProps,
    rootRef: handleRef
  }), [getRootProps, handleRef]);
}