'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { useNumberFieldContext } from '../Root/NumberFieldContext';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
/**
 * The increment stepper button.
 *
 * Demos:
 *
 * - [Number Field](https://base-ui.netlify.app/components/react-number-field/)
 *
 * API:
 *
 * - [NumberFieldIncrement API](https://base-ui.netlify.app/components/react-number-field/#api-reference-NumberFieldIncrement)
 */
const NumberFieldIncrement = /*#__PURE__*/React.forwardRef(function NumberFieldIncrement(props, forwardedRef) {
  const {
    render,
    className,
    ...otherProps
  } = props;
  const {
    getIncrementButtonProps,
    ownerState
  } = useNumberFieldContext('Increment');
  const {
    renderElement
  } = useComponentRenderer({
    propGetter: getIncrementButtonProps,
    ref: forwardedRef,
    render: render ?? 'button',
    ownerState,
    className,
    extraProps: otherProps
  });
  return renderElement();
});
process.env.NODE_ENV !== "production" ? NumberFieldIncrement.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func])
} : void 0;
export { NumberFieldIncrement };