import * as React from 'react';
import { UseNumberFieldRoot } from './useNumberFieldRoot';
import type { BaseUIComponentProps } from '../../utils/types';
import type { FieldRootOwnerState } from '../../Field/Root/FieldRoot.types';
/**
 * The foundation for building custom-styled number fields.
 *
 * Demos:
 *
 * - [Number Field](https://base-ui.netlify.app/components/react-number-field/)
 *
 * API:
 *
 * - [NumberFieldRoot API](https://base-ui.netlify.app/components/react-number-field/#api-reference-NumberFieldRoot)
 */
declare const NumberFieldRoot: React.ForwardRefExoticComponent<NumberFieldRoot.Props & React.RefAttributes<HTMLDivElement>>;
export declare namespace NumberFieldRoot {
    interface Props extends UseNumberFieldRoot.Parameters, Omit<BaseUIComponentProps<'div', OwnerState>, 'onChange' | 'defaultValue'> {
    }
    interface OwnerState extends FieldRootOwnerState {
        /**
         * The raw number value of the input element.
         */
        value: number | null;
        /**
         * The string value of the input element.
         */
        inputValue: string;
        /**
         * If `true`, the input element is required.
         */
        required: boolean;
        /**
         * If `true`, the input element is disabled.
         */
        disabled: boolean;
        /**
         * If `true`, the input element is invalid.
         */
        invalid: boolean;
        /**
         * If `true`, the input element is read only.
         */
        readOnly: boolean;
        /**
         * If `true`, the value is being scrubbed.
         */
        scrubbing: boolean;
    }
}
export { NumberFieldRoot };
