import * as React from 'react';
import type { BaseUIComponentProps } from '../../utils/types';
import type { NumberFieldRoot } from '../Root/NumberFieldRoot';
/**
 * The scrub area element.
 *
 * Demos:
 *
 * - [Number Field](https://base-ui.netlify.app/components/react-number-field/)
 *
 * API:
 *
 * - [NumberFieldScrubArea API](https://base-ui.netlify.app/components/react-number-field/#api-reference-NumberFieldScrubArea)
 */
declare const NumberFieldScrubArea: React.ForwardRefExoticComponent<NumberFieldScrubArea.Props & React.RefAttributes<HTMLSpanElement>>;
declare namespace NumberFieldScrubArea {
    interface OwnerState extends NumberFieldRoot.OwnerState {
    }
    interface Props extends BaseUIComponentProps<'span', OwnerState> {
        /**
         * The direction that the scrub area should change the value.
         * @default 'vertical'
         */
        direction?: 'vertical' | 'horizontal';
        /**
         * Determines the number of pixels the cursor must move before the value changes. A higher value
         * will make the scrubbing less sensitive.
         * @default 2
         */
        pixelSensitivity?: number;
        /**
         * If specified, how much the cursor can move around the center of the scrub area element before
         * it will loop back around.
         */
        teleportDistance?: number | undefined;
    }
}
export { NumberFieldScrubArea };
