import * as React from 'react';
import type { Alignment, Side } from '../../utils/useAnchorPositioning';
import type { BaseUIComponentProps } from '../../utils/types';
/**
 * Renders an arrow that points to the center of the anchor element.
 *
 * Demos:
 *
 * - [Popover](https://base-ui.netlify.app/components/react-popover/)
 *
 * API:
 *
 * - [PopoverArrow API](https://base-ui.netlify.app/components/react-popover/#api-reference-PopoverArrow)
 */
declare const PopoverArrow: React.ForwardRefExoticComponent<PopoverArrow.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace PopoverArrow {
    interface OwnerState {
        open: boolean;
        side: Side;
        alignment: Alignment;
        arrowUncentered: boolean;
    }
    interface Props extends BaseUIComponentProps<'div', OwnerState> {
        /**
         * If `true`, the arrow is hidden when it can't point to the center of the anchor element.
         * @default false
         */
        hideWhenUncentered?: boolean;
    }
}
export { PopoverArrow };
