import * as React from 'react';
import type { BaseUIComponentProps } from '../../utils/types';
/**
 * Renders a backdrop for the popover.
 *
 * Demos:
 *
 * - [Popover](https://base-ui.netlify.app/components/react-popover/)
 *
 * API:
 *
 * - [PopoverBackdrop API](https://base-ui.netlify.app/components/react-popover/#api-reference-PopoverBackdrop)
 */
declare const PopoverBackdrop: React.ForwardRefExoticComponent<PopoverBackdrop.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace PopoverBackdrop {
    interface OwnerState {
        open: boolean;
    }
    interface Props extends BaseUIComponentProps<'div', OwnerState> {
        /**
         * If `true`, the backdrop remains mounted when the popover content is closed.
         * @default false
         */
        keepMounted?: boolean;
        /**
         * The container element to which the backdrop is appended to.
         * @default false
         */
        container?: HTMLElement | null | React.MutableRefObject<HTMLElement | null>;
    }
}
export { PopoverBackdrop };
