import * as React from 'react';
import { usePopoverPositioner } from './usePopoverPositioner';
import type { BaseUIComponentProps } from '../../utils/types';
import type { Side, Alignment } from '../../utils/useAnchorPositioning';
/**
 * The popover positioner element.
 *
 * Demos:
 *
 * - [Popover](https://base-ui.netlify.app/components/react-popover/)
 *
 * API:
 *
 * - [PopoverPositioner API](https://base-ui.netlify.app/components/react-popover/#api-reference-PopoverPositioner)
 */
declare const PopoverPositioner: React.ForwardRefExoticComponent<PopoverPositioner.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace PopoverPositioner {
    interface OwnerState {
        open: boolean;
        side: Side;
        alignment: Alignment;
    }
    interface Props extends usePopoverPositioner.SharedParameters, BaseUIComponentProps<'div', OwnerState> {
        /**
         * The element the popover positioner element is appended to.
         */
        container?: HTMLElement | null | React.MutableRefObject<HTMLElement | null>;
    }
}
export { PopoverPositioner };
