import * as React from 'react';
import { mergeReactProps } from '../../utils/mergeReactProps';
import { useAnchorPositioning } from '../../utils/useAnchorPositioning';
import { getInertValue } from '../../utils/getInertValue';
export function usePopoverPositioner(params) {
  const {
    open = false,
    keepMounted = false
  } = params;
  const {
    positionerStyles,
    arrowStyles,
    hidden,
    arrowRef,
    arrowUncentered,
    renderedSide,
    renderedAlignment,
    positionerContext
  } = useAnchorPositioning(params);
  const getPositionerProps = React.useCallback((externalProps = {}) => {
    const hiddenStyles = {};
    if (keepMounted && !open || hidden) {
      hiddenStyles.pointerEvents = 'none';
    }
    return mergeReactProps(externalProps, {
      role: 'presentation',
      // @ts-ignore
      inert: getInertValue(open),
      style: {
        ...positionerStyles,
        ...hiddenStyles,
        zIndex: 2147483647 // max z-index
      }
    });
  }, [positionerStyles, open, keepMounted, hidden]);
  return React.useMemo(() => ({
    getPositionerProps,
    arrowRef,
    arrowUncentered,
    arrowStyles,
    side: renderedSide,
    alignment: renderedAlignment,
    positionerContext
  }), [getPositionerProps, arrowRef, arrowUncentered, arrowStyles, renderedSide, renderedAlignment, positionerContext]);
}