'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
import { usePopoverRootContext } from '../Root/PopoverRootContext';
import { usePopoverTitle } from './usePopoverTitle';
const ownerState = {};

/**
 * Renders a title element that labels the popover.
 *
 * Demos:
 *
 * - [Popover](https://base-ui.netlify.app/components/react-popover/)
 *
 * API:
 *
 * - [PopoverTitle API](https://base-ui.netlify.app/components/react-popover/#api-reference-PopoverTitle)
 */
const PopoverTitle = /*#__PURE__*/React.forwardRef(function PopoverTitle(props, forwardedRef) {
  const {
    render,
    className,
    ...otherProps
  } = props;
  const {
    setTitleId
  } = usePopoverRootContext();
  const {
    getTitleProps
  } = usePopoverTitle({
    titleId: otherProps.id,
    setTitleId
  });
  const {
    renderElement
  } = useComponentRenderer({
    propGetter: getTitleProps,
    render: render ?? 'h2',
    className,
    ownerState,
    ref: forwardedRef,
    extraProps: otherProps
  });
  return renderElement();
});
process.env.NODE_ENV !== "production" ? PopoverTitle.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * @ignore
   */
  id: PropTypes.string,
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func])
} : void 0;
export { PopoverTitle };