'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { PreviewCardRootContext } from './PreviewCardContext';
import { usePreviewCardRoot } from './usePreviewCardRoot';
import { CLOSE_DELAY, OPEN_DELAY } from '../utils/constants';

/**
 *
 * Demos:
 *
 * - [Preview Card](https://base-ui.netlify.app/components/react-preview-card/)
 *
 * API:
 *
 * - [PreviewCardRoot API](https://base-ui.netlify.app/components/react-preview-card/#api-reference-PreviewCardRoot)
 */
import { jsx as _jsx } from "react/jsx-runtime";
function PreviewCardRoot(props) {
  const {
    delayType = 'rest',
    delay,
    closeDelay,
    animated = true
  } = props;
  const delayWithDefault = delay ?? OPEN_DELAY;
  const closeDelayWithDefault = closeDelay ?? CLOSE_DELAY;
  const {
    open,
    setOpen,
    mounted,
    setMounted,
    triggerElement,
    setTriggerElement,
    positionerElement,
    setPositionerElement,
    popupRef,
    instantType,
    getRootTriggerProps,
    getRootPopupProps,
    floatingRootContext,
    transitionStatus
  } = usePreviewCardRoot({
    animated,
    delay,
    delayType,
    closeDelay,
    open: props.open,
    onOpenChange: props.onOpenChange,
    defaultOpen: props.defaultOpen
  });
  const contextValue = React.useMemo(() => ({
    delay: delayWithDefault,
    delayType,
    closeDelay: closeDelayWithDefault,
    open,
    setOpen,
    triggerElement,
    setTriggerElement,
    positionerElement,
    setPositionerElement,
    popupRef,
    mounted,
    setMounted,
    instantType,
    getRootTriggerProps,
    getRootPopupProps,
    floatingRootContext,
    transitionStatus
  }), [delayWithDefault, delayType, closeDelayWithDefault, open, setOpen, triggerElement, setTriggerElement, positionerElement, setPositionerElement, popupRef, mounted, setMounted, instantType, getRootTriggerProps, getRootPopupProps, floatingRootContext, transitionStatus]);
  return /*#__PURE__*/_jsx(PreviewCardRootContext.Provider, {
    value: contextValue,
    children: props.children
  });
}
process.env.NODE_ENV !== "production" ? PreviewCardRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * Whether the preview card can animate, adding animation-related attributes and allowing for exit
   * animations to play. Useful to disable in tests to remove async behavior.
   * @default true
   */
  animated: PropTypes.bool,
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * The delay in milliseconds until the preview card popup is closed when `openOnHover` is `true`.
   * @default 300
   */
  closeDelay: PropTypes.number,
  /**
   * Whether the preview card popup is open by default. Use when uncontrolled.
   * @default false
   */
  defaultOpen: PropTypes.bool,
  /**
   * The delay in milliseconds until the preview card popup is opened when `openOnHover` is `true`.
   * @default 600
   */
  delay: PropTypes.number,
  /**
   * The delay type to use when the preview card is triggered by hover. `rest` means the `delay`
   * represents how long the user's cursor must rest on the trigger before the preview card popup is
   * opened. `hover` means the `delay` represents how long to wait as soon as the user's cursor has
   * entered the trigger.
   * @default 'rest'
   */
  delayType: PropTypes.oneOf(['hover', 'rest']),
  /**
   * Callback fired when the preview card popup is requested to be opened or closed. Use when
   * controlled.
   */
  onOpenChange: PropTypes.func,
  /**
   * Whether the preview card popup is open. Use when controlled.
   * @default false
   */
  open: PropTypes.bool
} : void 0;
export { PreviewCardRoot };