'use client';

import * as React from 'react';
import { mergeReactProps } from '../../utils/mergeReactProps';
function getDefaultAriaValueText(value) {
  if (value === null) {
    return 'indeterminate progress';
  }
  return `${value}%`;
}
function useProgressRoot(parameters) {
  const {
    'aria-label': ariaLabel,
    'aria-labelledby': ariaLabelledby,
    'aria-valuetext': ariaValuetext,
    direction = 'ltr',
    getAriaLabel,
    getAriaValueText,
    max = 100,
    min = 0,
    value
  } = parameters;
  let state = 'indeterminate';
  if (Number.isFinite(value)) {
    state = value === max ? 'complete' : 'progressing';
  }
  const getRootProps = React.useCallback((externalProps = {}) => mergeReactProps(externalProps, {
    'aria-label': getAriaLabel ? getAriaLabel(value) : ariaLabel,
    'aria-labelledby': ariaLabelledby,
    'aria-valuemax': max,
    'aria-valuemin': min,
    'aria-valuenow': value ?? undefined,
    'aria-valuetext': getAriaValueText ? getAriaValueText(value) : ariaValuetext ?? getDefaultAriaValueText(value),
    dir: direction,
    role: 'progressbar'
  }), [ariaLabel, ariaLabelledby, ariaValuetext, direction, getAriaLabel, getAriaValueText, max, min, value]);
  return {
    getRootProps,
    direction,
    max,
    min,
    value,
    state
  };
}
export { useProgressRoot };