import * as React from 'react';
import type { BaseUIComponentProps } from '../../utils/types';
/**
 *
 * Demos:
 *
 * - [Radio Group](https://base-ui.netlify.app/components/react-radio-group/)
 *
 * API:
 *
 * - [RadioGroupRoot API](https://base-ui.netlify.app/components/react-radio-group/#api-reference-RadioGroupRoot)
 */
declare const RadioGroupRoot: React.ForwardRefExoticComponent<RadioGroupRoot.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace RadioGroupRoot {
    interface OwnerState {
        disabled: boolean | undefined;
        readOnly: boolean | undefined;
    }
    interface Props extends Omit<BaseUIComponentProps<'div', OwnerState>, 'value' | 'defaultValue'> {
        /**
         * Determines if the radio group is disabled.
         * @default false
         */
        disabled?: boolean;
        /**
         * Determines if the radio group is readonly.
         * @default false
         */
        readOnly?: boolean;
        /**
         * Determines if the radio group is required.
         * @default false
         */
        required?: boolean;
        /**
         * The name of the radio group submitted with the form data.
         */
        name?: string;
        /**
         * The value of the selected radio button. Use when controlled.
         */
        value?: unknown;
        /**
         * The default value of the selected radio button. Use when uncontrolled.
         */
        defaultValue?: unknown;
        /**
         * Callback fired when the value changes.
         */
        onValueChange?: (value: unknown, event: React.ChangeEvent<HTMLInputElement>) => void;
    }
}
export { RadioGroupRoot };
