'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { CompositeRoot } from '../../Composite/Root/CompositeRoot';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
import { useEventCallback } from '../../utils/useEventCallback';
import { useRadioGroupRoot } from './useRadioGroupRoot';
import { RadioGroupRootContext } from './RadioGroupRootContext';
import { useFieldRootContext } from '../../Field/Root/FieldRootContext';
/**
 *
 * Demos:
 *
 * - [Radio Group](https://base-ui.netlify.app/components/react-radio-group/)
 *
 * API:
 *
 * - [RadioGroupRoot API](https://base-ui.netlify.app/components/react-radio-group/#api-reference-RadioGroupRoot)
 */
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const RadioGroupRoot = /*#__PURE__*/React.forwardRef(function RadioGroupRoot(props, forwardedRef) {
  const {
    render,
    className,
    disabled: disabledProp,
    readOnly,
    required,
    onValueChange: onValueChangeProp,
    name,
    ...otherProps
  } = props;
  const {
    getRootProps,
    getInputProps,
    checkedValue,
    setCheckedValue,
    touched,
    setTouched
  } = useRadioGroupRoot(props);
  const {
    ownerState: fieldOwnerState,
    disabled: fieldDisabled
  } = useFieldRootContext();
  const disabled = fieldDisabled || disabledProp;
  const onValueChange = useEventCallback(onValueChangeProp ?? (() => {}));
  const ownerState = React.useMemo(() => ({
    ...fieldOwnerState,
    disabled: disabled ?? false,
    required: required ?? false,
    readOnly: readOnly ?? false
  }), [fieldOwnerState, disabled, readOnly, required]);
  const contextValue = React.useMemo(() => ({
    checkedValue,
    setCheckedValue,
    onValueChange,
    disabled,
    readOnly,
    required,
    touched,
    setTouched
  }), [checkedValue, setCheckedValue, onValueChange, disabled, readOnly, required, touched, setTouched]);
  const {
    renderElement
  } = useComponentRenderer({
    propGetter: getRootProps,
    render: render ?? 'div',
    ref: forwardedRef,
    className,
    ownerState,
    extraProps: otherProps
  });
  return /*#__PURE__*/_jsxs(RadioGroupRootContext.Provider, {
    value: contextValue,
    children: [/*#__PURE__*/_jsx(CompositeRoot, {
      render: renderElement()
    }), /*#__PURE__*/_jsx("input", {
      ...getInputProps()
    })]
  });
});
process.env.NODE_ENV !== "production" ? RadioGroupRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * The default value of the selected radio button. Use when uncontrolled.
   */
  defaultValue: PropTypes.any,
  /**
   * Determines if the radio group is disabled.
   * @default false
   */
  disabled: PropTypes.bool,
  /**
   * The name of the radio group submitted with the form data.
   */
  name: PropTypes.string,
  /**
   * Callback fired when the value changes.
   */
  onValueChange: PropTypes.func,
  /**
   * Determines if the radio group is readonly.
   * @default false
   */
  readOnly: PropTypes.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func]),
  /**
   * Determines if the radio group is required.
   * @default false
   */
  required: PropTypes.bool,
  /**
   * The value of the selected radio button. Use when controlled.
   */
  value: PropTypes.any
} : void 0;
export { RadioGroupRoot };