'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { TabsContext } from './TabsContext';
import { CompoundComponentContext } from '../../useCompound';
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * Sets up the contexts for the underlying Tab and TabPanel components.
 *
 * @ignore - do not document.
 */
function TabsProvider(props) {
  const {
    value: valueProp,
    children
  } = props;
  const {
    direction,
    getItemIndex,
    onSelected,
    orientation,
    registerItem,
    registerTabIdLookup,
    totalSubitemCount,
    value,
    getTabId,
    getTabPanelId,
    tabActivationDirection
  } = valueProp;
  const compoundComponentContextValue = React.useMemo(() => ({
    getItemIndex,
    registerItem,
    totalSubitemCount
  }), [registerItem, getItemIndex, totalSubitemCount]);
  const tabsContextValue = React.useMemo(() => ({
    direction,
    getTabId,
    getTabPanelId,
    onSelected,
    orientation,
    registerTabIdLookup,
    value,
    tabActivationDirection
  }), [direction, getTabId, getTabPanelId, onSelected, orientation, registerTabIdLookup, value, tabActivationDirection]);
  return /*#__PURE__*/_jsx(CompoundComponentContext.Provider, {
    value: compoundComponentContextValue,
    children: /*#__PURE__*/_jsx(TabsContext.Provider, {
      value: tabsContextValue,
      children: children
    })
  });
}
process.env.NODE_ENV !== "production" ? TabsProvider.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * @ignore
   */
  value: PropTypes.shape({
    direction: PropTypes.oneOf(['ltr', 'rtl']).isRequired,
    getItemIndex: PropTypes.func.isRequired,
    getTabId: PropTypes.func.isRequired,
    getTabPanelId: PropTypes.func.isRequired,
    onSelected: PropTypes.func.isRequired,
    orientation: PropTypes.oneOf(['horizontal', 'vertical']).isRequired,
    registerItem: PropTypes.func.isRequired,
    registerTabIdLookup: PropTypes.func.isRequired,
    tabActivationDirection: PropTypes.oneOf(['down', 'left', 'none', 'right', 'up']).isRequired,
    totalSubitemCount: PropTypes.number.isRequired,
    value: PropTypes.any
  }).isRequired
} : void 0;
export { TabsProvider };