'use client';

import * as React from 'react';
import { useCompoundParent } from '../../useCompound';
import { mergeReactProps } from '../../utils/mergeReactProps';
import { useControlled } from '../../utils/useControlled';
function useTabsRoot(parameters) {
  const {
    value: valueProp,
    defaultValue,
    onValueChange,
    orientation = 'horizontal',
    direction = 'ltr'
  } = parameters;
  const [value, setValue] = useControlled({
    controlled: valueProp,
    default: defaultValue,
    name: 'Tabs',
    state: 'value'
  });
  const [tabActivationDirection, setTabActivationDirection] = React.useState('none');
  const onSelected = React.useCallback((event, newValue, activationDirection) => {
    setValue(newValue);
    setTabActivationDirection(activationDirection);
    onValueChange?.(newValue, event);
  }, [onValueChange, setValue]);
  const {
    subitems: tabPanels,
    contextValue: compoundComponentContextValue
  } = useCompoundParent();
  const tabIdLookup = React.useRef(() => undefined);
  const getTabPanelId = React.useCallback(tabValue => {
    return tabPanels.get(tabValue)?.id;
  }, [tabPanels]);
  const getTabId = React.useCallback(tabPanelId => {
    return tabIdLookup.current(tabPanelId);
  }, []);
  const registerTabIdLookup = React.useCallback(lookupFunction => {
    tabIdLookup.current = lookupFunction;
  }, []);
  const getRootProps = React.useCallback((otherProps = {}) => mergeReactProps(otherProps, {
    dir: direction
  }), [direction]);
  return {
    contextValue: {
      direction,
      getTabId,
      getTabPanelId,
      onSelected,
      orientation,
      registerTabIdLookup,
      value,
      tabActivationDirection,
      ...compoundComponentContextValue
    },
    getRootProps,
    tabActivationDirection
  };
}
export { useTabsRoot };