'use client';

import * as React from 'react';
import { useTabsContext } from '../Root/TabsContext';
import { useCompoundItem } from '../../useCompound';
import { useId } from '../../utils/useId';
import { useForkRef } from '../../utils/useForkRef';
import { mergeReactProps } from '../../utils/mergeReactProps';
function tabPanelValueGenerator(otherTabPanelValues) {
  return otherTabPanelValues.size;
}
function useTabPanel(parameters) {
  const {
    value: valueParam,
    id: idParam,
    rootRef: externalRef
  } = parameters;
  const {
    value: selectedTabValue,
    getTabId,
    orientation,
    direction,
    tabActivationDirection
  } = useTabsContext();
  const id = useId(idParam);
  const ref = React.useRef(null);
  const handleRef = useForkRef(ref, externalRef);
  const metadata = React.useMemo(() => ({
    id,
    ref
  }), [id]);
  const {
    id: value
  } = useCompoundItem(valueParam ?? tabPanelValueGenerator, metadata);
  const hidden = value !== selectedTabValue;
  const correspondingTabId = value !== undefined ? getTabId(value) : undefined;
  const getRootProps = React.useCallback((externalProps = {}) => {
    return mergeReactProps(externalProps, {
      'aria-labelledby': correspondingTabId ?? undefined,
      hidden,
      id: id ?? undefined,
      role: 'tabpanel',
      tabIndex: hidden ? -1 : 0,
      ref: handleRef
    });
  }, [correspondingTabId, handleRef, hidden, id]);
  return {
    hidden,
    getRootProps,
    rootRef: handleRef,
    orientation,
    direction,
    tabActivationDirection
  };
}
export { useTabPanel };