'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { TabsListContext } from './TabsListContext';
import { ListContext } from '../../useList/ListContext';
import { CompoundComponentContext } from '../../useCompound';
import { refType } from '../../utils/proptypes';
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * Sets up the contexts for the underlying Tab components.
 *
 * @ignore - do not document.
 */
function TabsListProvider(props) {
  const {
    value,
    children
  } = props;
  const {
    dispatch,
    getItemIndex,
    getItemState,
    registerItem,
    totalSubitemCount,
    activateOnFocus,
    getTabElement,
    tabsListRef
  } = value;
  const listContextValue = React.useMemo(() => ({
    dispatch,
    getItemState,
    getItemIndex
  }), [dispatch, getItemIndex, getItemState]);
  const compoundComponentContextValue = React.useMemo(() => ({
    getItemIndex,
    registerItem,
    totalSubitemCount
  }), [registerItem, getItemIndex, totalSubitemCount]);
  const tabsListContextValue = React.useMemo(() => ({
    activateOnFocus,
    getTabElement,
    tabsListRef
  }), [activateOnFocus, getTabElement, tabsListRef]);
  return /*#__PURE__*/_jsx(CompoundComponentContext.Provider, {
    value: compoundComponentContextValue,
    children: /*#__PURE__*/_jsx(ListContext.Provider, {
      value: listContextValue,
      children: /*#__PURE__*/_jsx(TabsListContext.Provider, {
        value: tabsListContextValue,
        children: children
      })
    })
  });
}
process.env.NODE_ENV !== "production" ? TabsListProvider.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * @ignore
   */
  value: PropTypes /* @typescript-to-proptypes-ignore */.shape({
    activateOnFocus: PropTypes.bool.isRequired,
    dispatch: PropTypes.func.isRequired,
    getItemIndex: PropTypes.func.isRequired,
    getItemState: PropTypes.func.isRequired,
    getTabElement: PropTypes.func.isRequired,
    registerItem: PropTypes.func.isRequired,
    tabsListRef: refType.isRequired,
    totalSubitemCount: PropTypes.number.isRequired
  }).isRequired
} : void 0;
export { TabsListProvider };