import * as React from 'react';
import type { BaseUIComponentProps } from '../../utils/types';
import type { Side, Alignment } from '../../utils/useAnchorPositioning';
/**
 * Renders an arrow that points to the center of the anchor element.
 *
 * Demos:
 *
 * - [Tooltip](https://base-ui.netlify.app/components/react-tooltip/)
 *
 * API:
 *
 * - [TooltipArrow API](https://base-ui.netlify.app/components/react-tooltip/#api-reference-TooltipArrow)
 */
declare const TooltipArrow: React.ForwardRefExoticComponent<TooltipArrow.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace TooltipArrow {
    interface OwnerState {
        open: boolean;
        side: Side;
        alignment: Alignment;
    }
    interface Props extends BaseUIComponentProps<'div', OwnerState> {
        /**
         * If `true`, the arrow will be hidden when it can't point to the center of the anchor element.
         * @default false
         */
        hideWhenUncentered?: boolean;
    }
}
export { TooltipArrow };
