'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { useComponentRenderer } from '../../utils/useComponentRenderer';
import { useTooltipRootContext } from '../Root/TooltipRootContext';
import { useTooltipPositionerContext } from '../Positioner/TooltipPositionerContext';
import { useForkRef } from '../../utils/useForkRef';
const customStyleHookMapping = {
  entering(value) {
    return value ? {
      'data-entering': ''
    } : null;
  },
  exiting(value) {
    return value ? {
      'data-exiting': ''
    } : null;
  },
  open(value) {
    return {
      'data-state': value ? 'open' : 'closed'
    };
  }
};

/**
 * The tooltip popup element.
 *
 * Demos:
 *
 * - [Tooltip](https://base-ui.netlify.app/components/react-tooltip/)
 *
 * API:
 *
 * - [TooltipPopup API](https://base-ui.netlify.app/components/react-tooltip/#api-reference-TooltipPopup)
 */
const TooltipPopup = /*#__PURE__*/React.forwardRef(function TooltipPopup(props, forwardedRef) {
  const {
    className,
    render,
    ...otherProps
  } = props;
  const {
    open,
    instantType,
    transitionStatus,
    getRootPopupProps,
    popupRef
  } = useTooltipRootContext();
  const {
    side,
    alignment
  } = useTooltipPositionerContext();
  const ownerState = React.useMemo(() => ({
    open,
    side,
    alignment,
    instant: instantType,
    entering: transitionStatus === 'entering',
    exiting: transitionStatus === 'exiting'
  }), [open, side, alignment, instantType, transitionStatus]);
  const mergedRef = useForkRef(popupRef, forwardedRef);

  // The content element needs to be a child of a wrapper floating element in order to avoid
  // conflicts with CSS transitions and the positioning transform.
  const {
    renderElement
  } = useComponentRenderer({
    propGetter: getRootPopupProps,
    render: render ?? 'div',
    className,
    ownerState,
    ref: mergedRef,
    extraProps: otherProps,
    customStyleHookMapping
  });
  return renderElement();
});
process.env.NODE_ENV !== "production" ? TooltipPopup.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /**
   * A function to customize rendering of the component.
   */
  render: PropTypes.oneOfType([PropTypes.element, PropTypes.func])
} : void 0;
export { TooltipPopup };