import * as React from 'react';
import { useTooltipPositioner } from './useTooltipPositioner';
import type { BaseUIComponentProps } from '../../utils/types';
import type { Side, Alignment } from '../../utils/useAnchorPositioning';
/**
 * The tooltip positioner element.
 *
 * Demos:
 *
 * - [Tooltip](https://base-ui.netlify.app/components/react-tooltip/)
 *
 * API:
 *
 * - [TooltipPositioner API](https://base-ui.netlify.app/components/react-tooltip/#api-reference-TooltipPositioner)
 */
declare const TooltipPositioner: React.ForwardRefExoticComponent<TooltipPositioner.Props & React.RefAttributes<HTMLDivElement>>;
declare namespace TooltipPositioner {
    interface OwnerState {
        open: boolean;
        side: Side;
        alignment: Alignment;
    }
    interface Props extends BaseUIComponentProps<'div', OwnerState>, useTooltipPositioner.SharedParameters {
        /**
         * The container element the tooltip positioner is appended to.
         */
        container?: HTMLElement | null | React.MutableRefObject<HTMLElement | null>;
    }
}
export { TooltipPositioner };
