import * as React from 'react';
import { mergeReactProps } from '../../utils/mergeReactProps';
import { useAnchorPositioning } from '../../utils/useAnchorPositioning';
export function useTooltipPositioner(params) {
  const {
    open = false,
    keepMounted = false,
    trackCursorAxis = 'none'
  } = params;
  const {
    positionerStyles,
    arrowStyles,
    hidden,
    arrowRef,
    arrowUncentered,
    renderedSide,
    renderedAlignment
  } = useAnchorPositioning(params);
  const getPositionerProps = React.useCallback((externalProps = {}) => {
    const hiddenStyles = {};
    if (keepMounted && !open || hidden) {
      hiddenStyles.pointerEvents = 'none';
    }
    if (trackCursorAxis === 'both') {
      hiddenStyles.pointerEvents = 'none';
    }
    return mergeReactProps(externalProps, {
      role: 'presentation',
      style: {
        ...positionerStyles,
        ...hiddenStyles,
        maxWidth: 'var(--available-width)',
        maxHeight: 'var(--available-height)',
        zIndex: 2147483647 // max z-index
      }
    });
  }, [positionerStyles, hidden, trackCursorAxis, open, keepMounted]);
  return React.useMemo(() => ({
    getPositionerProps,
    arrowStyles,
    arrowRef,
    arrowUncentered,
    side: renderedSide,
    alignment: renderedAlignment
  }), [getPositionerProps, arrowRef, arrowUncentered, renderedSide, renderedAlignment, arrowStyles]);
}