import * as React from 'react';
/**
 * Provides a shared delay for tooltips so that once a tooltip is shown, the rest of the tooltips in
 * the group will not wait for the delay before showing.
 *
 * Demos:
 *
 * - [Tooltip](https://base-ui.netlify.app/components/react-tooltip/)
 *
 * API:
 *
 * - [TooltipProvider API](https://base-ui.netlify.app/components/react-tooltip/#api-reference-TooltipProvider)
 */
declare function TooltipProvider(props: TooltipProvider.Props): React.JSX.Element;
declare namespace TooltipProvider {
    var propTypes: any;
}
declare namespace TooltipProvider {
    interface Props {
        children?: React.ReactNode;
        /**
         * The delay in milliseconds until tooltips within the group are open.
         */
        delay?: number;
        /**
         * The delay in milliseconds until tooltips within the group are closed.
         */
        closeDelay?: number;
        /**
         * The timeout in milliseconds until the grouping logic is no longer active after the last tooltip
         * in the group has closed.
         * @default 400
         */
        timeout?: number;
    }
}
export { TooltipProvider };
