'use client';

import * as React from 'react';
import PropTypes from 'prop-types';
import { FloatingDelayGroup } from '@floating-ui/react';

/**
 * Provides a shared delay for tooltips so that once a tooltip is shown, the rest of the tooltips in
 * the group will not wait for the delay before showing.
 *
 * Demos:
 *
 * - [Tooltip](https://base-ui.netlify.app/components/react-tooltip/)
 *
 * API:
 *
 * - [TooltipProvider API](https://base-ui.netlify.app/components/react-tooltip/#api-reference-TooltipProvider)
 */
import { jsx as _jsx } from "react/jsx-runtime";
function TooltipProvider(props) {
  const {
    delay,
    closeDelay,
    timeout = 400
  } = props;
  return /*#__PURE__*/_jsx(FloatingDelayGroup, {
    delay: {
      open: delay ?? 0,
      close: closeDelay ?? 0
    },
    timeoutMs: timeout,
    children: props.children
  });
}
process.env.NODE_ENV !== "production" ? TooltipProvider.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: PropTypes.node,
  /**
   * The delay in milliseconds until tooltips within the group are closed.
   */
  closeDelay: PropTypes.number,
  /**
   * The delay in milliseconds until tooltips within the group are open.
   */
  delay: PropTypes.number,
  /**
   * The timeout in milliseconds until the grouping logic is no longer active after the last tooltip
   * in the group has closed.
   * @default 400
   */
  timeout: PropTypes.number
} : void 0;
export { TooltipProvider };