import * as React from 'react';
import { type OpenChangeReason, type FloatingRootContext } from '@floating-ui/react';
import type { TransitionStatus } from '../../utils/useTransitionStatus';
import type { GenericHTMLProps } from '../../utils/types';
export declare function useTooltipRoot(params: useTooltipRoot.Parameters): useTooltipRoot.ReturnValue;
export declare namespace useTooltipRoot {
    interface Parameters {
        /**
         * Whether the tooltip popup is open by default. Use when uncontrolled.
         * @default false
         */
        defaultOpen?: boolean;
        /**
         * Whether the tooltip popup is open. Use when controlled.
         * @default false
         */
        open?: boolean;
        /**
         * Callback fired when the tooltip popup is requested to be opened or closed. Use when controlled.
         */
        onOpenChange?: (isOpen: boolean, event?: Event, reason?: OpenChangeReason) => void;
        /**
         * Whether the user can move their cursor from the trigger element toward the tooltip popup element
         * without it closing using a "safe polygon" technique.
         * @default true
         */
        hoverable?: boolean;
        /**
         * Whether the tooltip can animate, adding animation-related attributes and allowing for exit
         * animations to play. Useful to disable in tests to remove async behavior.
         * @default true
         */
        animated?: boolean;
        /**
         * Determines which axis the tooltip should track the cursor on.
         * @default 'none'
         */
        trackCursorAxis?: 'none' | 'x' | 'y' | 'both';
        /**
         * The delay in milliseconds until the tooltip popup is opened.
         * @default 600
         */
        delay?: number;
        /**
         * The delay in milliseconds until the tooltip popup is closed.
         * @default 0
         */
        closeDelay?: number;
        /**
         * The delay type to use. `rest` means the `delay` represents how long the user's cursor must
         * rest on the trigger before the tooltip popup is opened. `hover` means the `delay` represents
         * how long to wait as soon as the user's cursor has entered the trigger.
         * @default 'rest'
         */
        delayType?: 'rest' | 'hover';
        /**
         * Whether the tooltip popup element stays mounted in the DOM when closed.
         * @default false
         */
        keepMounted?: boolean;
    }
    interface ReturnValue {
        open: boolean;
        setOpen: (value: boolean, event?: Event, reason?: OpenChangeReason) => void;
        mounted: boolean;
        setMounted: React.Dispatch<React.SetStateAction<boolean>>;
        getRootTriggerProps: (externalProps?: GenericHTMLProps) => GenericHTMLProps;
        getRootPopupProps: (externalProps?: GenericHTMLProps) => GenericHTMLProps;
        floatingRootContext: FloatingRootContext;
        instantType: 'delay' | 'dismiss' | 'focus' | undefined;
        transitionStatus: TransitionStatus;
        triggerElement: Element | null;
        positionerElement: HTMLElement | null;
        setTriggerElement: React.Dispatch<React.SetStateAction<Element | null>>;
        setPositionerElement: React.Dispatch<React.SetStateAction<HTMLElement | null>>;
        popupRef: React.RefObject<HTMLElement | null>;
    }
}
