"use strict";
'use client';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UseCheckboxGroupParent = void 0;
exports.useCheckboxGroupParent = useCheckboxGroupParent;
var React = _interopRequireWildcard(require("react"));
var _useId = require("../../utils/useId");
var _useEventCallback = require("../../utils/useEventCallback");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 *
 * API:
 *
 * - [useCheckboxGroupParent API](https://mui.com/base-ui/api/use-checkbox-group-parent/)
 */
function useCheckboxGroupParent(params) {
  const {
    allValues = [],
    value = [],
    onValueChange: onValueChangeProp = () => {},
    preserveChildStates = false
  } = params;
  const uncontrolledStateRef = React.useRef(value);
  const [status, setStatus] = React.useState('mixed');
  const id = (0, _useId.useId)();
  const checked = value.length === allValues.length;
  const indeterminate = value.length !== allValues.length && value.length > 0;
  const onValueChange = (0, _useEventCallback.useEventCallback)(onValueChangeProp);
  const getParentProps = React.useCallback(() => ({
    id,
    indeterminate,
    checked,
    'aria-controls': allValues.map(v => `${id}-${v}`).join(' '),
    onCheckedChange(_, event) {
      const uncontrolledState = uncontrolledStateRef.current;
      const allOnOrOff = uncontrolledState.length === allValues.length || uncontrolledState.length === 0;
      if (allOnOrOff) {
        if (value.length === allValues.length) {
          onValueChange([], event);
        } else {
          onValueChange(allValues, event);
        }
        return;
      }
      if (preserveChildStates) {
        if (status === 'mixed') {
          onValueChange(allValues, event);
          setStatus('on');
        } else if (status === 'on') {
          onValueChange([], event);
          setStatus('off');
        } else if (status === 'off') {
          onValueChange(uncontrolledState, event);
          setStatus('mixed');
        }
      } else if (checked) {
        onValueChange([], event);
        setStatus('off');
      } else {
        onValueChange(allValues, event);
        setStatus('on');
      }
    }
  }), [allValues, checked, id, indeterminate, onValueChange, preserveChildStates, status, value.length]);
  const getChildProps = React.useCallback(name => ({
    name,
    id: `${id}-${name}`,
    checked: value.includes(name),
    onCheckedChange(nextChecked, event) {
      const newValue = [...value];
      if (nextChecked) {
        newValue.push(name);
      } else {
        newValue.splice(newValue.indexOf(name), 1);
      }
      uncontrolledStateRef.current = newValue;
      onValueChange(newValue, event);
      setStatus('mixed');
    }
  }), [id, onValueChange, value]);
  return React.useMemo(() => ({
    id,
    indeterminate,
    getParentProps,
    getChildProps
  }), [id, indeterminate, getParentProps, getChildProps]);
}
let UseCheckboxGroupParent = exports.UseCheckboxGroupParent = void 0;