"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CheckboxGroupRoot = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _useCheckboxGroupRoot = require("./useCheckboxGroupRoot");
var _CheckboxGroupRootContext = require("./CheckboxGroupRootContext");
var _FieldRootContext = require("../../Field/Root/FieldRootContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * The foundation for building custom-styled checkbox groups.
 *
 * Demos:
 *
 * - [Checkbox Group](https://base-ui.netlify.app/components/react-checkbox-group/)
 *
 * API:
 *
 * - [CheckboxGroupRoot API](https://base-ui.netlify.app/components/react-checkbox-group/#api-reference-CheckboxGroupRoot)
 */
const CheckboxGroupRoot = exports.CheckboxGroupRoot = /*#__PURE__*/React.forwardRef(function CheckboxGroupRoot(props, forwardedRef) {
  const {
    render,
    className,
    value: externalValue,
    defaultValue,
    onValueChange,
    allValues,
    disabled: disabledProp = false,
    preserveChildStates = false,
    ...otherProps
  } = props;
  const {
    disabled: fieldDisabled,
    ownerState: fieldOwnerState
  } = (0, _FieldRootContext.useFieldRootContext)();
  const disabled = fieldDisabled || disabledProp;
  const {
    getRootProps,
    value,
    setValue,
    parent
  } = (0, _useCheckboxGroupRoot.useCheckboxGroupRoot)({
    value: externalValue,
    allValues,
    defaultValue,
    onValueChange,
    preserveChildStates
  });
  const ownerState = React.useMemo(() => ({
    ...fieldOwnerState,
    disabled
  }), [fieldOwnerState, disabled]);
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    propGetter: getRootProps,
    render: render ?? 'div',
    className,
    ownerState,
    ref: forwardedRef,
    extraProps: otherProps
  });
  const contextValue = React.useMemo(() => ({
    allValues,
    value,
    setValue,
    parent
  }), [allValues, value, setValue, parent]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_CheckboxGroupRootContext.CheckboxGroupRootContext.Provider, {
    value: contextValue,
    children: renderElement()
  });
});
process.env.NODE_ENV !== "production" ? CheckboxGroupRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * All values of the checkboxes in the group.
   */
  allValues: _propTypes.default.arrayOf(_propTypes.default.string),
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * The default checked values of the checkbox group. Use when uncontrolled.
   */
  defaultValue: _propTypes.default.arrayOf(_propTypes.default.string),
  /**
   * Whether the checkbox group is disabled.
   * @default false
   */
  disabled: _propTypes.default.bool,
  /**
   * A callback function that is called when the value of the checkbox group changes.
   * Use when controlled.
   */
  onValueChange: _propTypes.default.func,
  /**
   * Whether the parent checkbox should preserve its child states when checked/unchecked, leading
   * to a tri-state checkbox group.
   * @default false
   */
  preserveChildStates: _propTypes.default.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func]),
  /**
   * The currently checked values of the checkbox group. Use when controlled.
   */
  value: _propTypes.default.arrayOf(_propTypes.default.string)
} : void 0;