"use strict";
'use client';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCompositeRoot = useCompositeRoot;
var React = _interopRequireWildcard(require("react"));
var _useEventCallback = require("../../utils/useEventCallback");
var _mergeReactProps = require("../../utils/mergeReactProps");
var _composite = require("../composite");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
// Advanced options of Composite, to be implemented later if needed.
const disabledIndices = undefined;

/**
 * @ignore - internal hook.
 */
function useCompositeRoot(params) {
  const {
    itemSizes,
    cols = 1,
    loop = true,
    dense = false,
    orientation = 'both',
    activeIndex: externalActiveIndex,
    onActiveIndexChange: externalSetActiveIndex
  } = params;
  const [internalActiveIndex, internalSetActiveIndex] = React.useState(0);
  const isGrid = cols > 1;
  const activeIndex = externalActiveIndex ?? internalActiveIndex;
  const onActiveIndexChange = (0, _useEventCallback.useEventCallback)(externalSetActiveIndex ?? internalSetActiveIndex);
  const elementsRef = React.useRef([]);
  const getRootProps = React.useCallback((externalProps = {}) => (0, _mergeReactProps.mergeReactProps)(externalProps, {
    'aria-orientation': orientation === 'both' ? undefined : orientation,
    onKeyDown(event) {
      if (!_composite.ALL_KEYS.includes(event.key)) {
        return;
      }
      let nextIndex = activeIndex;
      const minIndex = (0, _composite.getMinIndex)(elementsRef, disabledIndices);
      const maxIndex = (0, _composite.getMaxIndex)(elementsRef, disabledIndices);
      if (isGrid) {
        const sizes = itemSizes || Array.from({
          length: elementsRef.current.length
        }, () => ({
          width: 1,
          height: 1
        }));
        // To calculate movements on the grid, we use hypothetical cell indices
        // as if every item was 1x1, then convert back to real indices.
        const cellMap = (0, _composite.buildCellMap)(sizes, cols, dense);
        const minGridIndex = cellMap.findIndex(index => index != null && !(0, _composite.isDisabled)(elementsRef.current, index, disabledIndices));
        // last enabled index
        const maxGridIndex = cellMap.reduce((foundIndex, index, cellIndex) => index != null && !(0, _composite.isDisabled)(elementsRef.current, index, disabledIndices) ? cellIndex : foundIndex, -1);
        nextIndex = cellMap[(0, _composite.getGridNavigatedIndex)({
          current: cellMap.map(itemIndex => itemIndex ? elementsRef.current[itemIndex] : null)
        }, {
          event,
          orientation,
          loop,
          cols,
          // treat undefined (empty grid spaces) as disabled indices so we
          // don't end up in them
          disabledIndices: (0, _composite.getCellIndices)([...(disabledIndices || elementsRef.current.map((_, index) => (0, _composite.isDisabled)(elementsRef.current, index) ? index : undefined)), undefined], cellMap),
          minIndex: minGridIndex,
          maxIndex: maxGridIndex,
          prevIndex: (0, _composite.getCellIndexOfCorner)(activeIndex > maxIndex ? minIndex : activeIndex, sizes, cellMap, cols,
          // use a corner matching the edge closest to the direction we're
          // moving in so we don't end up in the same item. Prefer
          // top/left over bottom/right.
          // eslint-disable-next-line no-nested-ternary
          event.key === _composite.ARROW_DOWN ? 'bl' : event.key === _composite.ARROW_RIGHT ? 'tr' : 'tl')
        })]; // navigated cell will never be nullish
      }
      const toEndKeys = {
        horizontal: [_composite.ARROW_RIGHT],
        vertical: [_composite.ARROW_DOWN],
        both: [_composite.ARROW_RIGHT, _composite.ARROW_DOWN]
      }[orientation];
      const toStartKeys = {
        horizontal: [_composite.ARROW_LEFT],
        vertical: [_composite.ARROW_UP],
        both: [_composite.ARROW_LEFT, _composite.ARROW_UP]
      }[orientation];
      const preventedKeys = isGrid ? _composite.ALL_KEYS : {
        horizontal: _composite.HORIZONTAL_KEYS,
        vertical: _composite.VERTICAL_KEYS,
        both: _composite.ALL_KEYS
      }[orientation];
      if (nextIndex === activeIndex && [...toEndKeys, ...toStartKeys].includes(event.key)) {
        if (loop && nextIndex === maxIndex && toEndKeys.includes(event.key)) {
          nextIndex = minIndex;
        } else if (loop && nextIndex === minIndex && toStartKeys.includes(event.key)) {
          nextIndex = maxIndex;
        } else {
          nextIndex = (0, _composite.findNonDisabledIndex)(elementsRef, {
            startingIndex: nextIndex,
            decrement: toStartKeys.includes(event.key),
            disabledIndices
          });
        }
      }
      if (nextIndex !== activeIndex && !(0, _composite.isIndexOutOfBounds)(elementsRef, nextIndex)) {
        event.stopPropagation();
        if (preventedKeys.includes(event.key)) {
          event.preventDefault();
        }
        onActiveIndexChange(nextIndex);

        // Wait for FocusManager `returnFocus` to execute.
        queueMicrotask(() => {
          elementsRef.current[nextIndex]?.focus();
        });
      }
    }
  }), [activeIndex, cols, dense, elementsRef, isGrid, itemSizes, loop, onActiveIndexChange, orientation]);
  return React.useMemo(() => ({
    getRootProps,
    activeIndex,
    onActiveIndexChange,
    elementsRef
  }), [getRootProps, activeIndex, onActiveIndexChange, elementsRef]);
}