"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DialogBackdrop = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _react2 = require("@floating-ui/react");
var _useDialogBackdrop = require("./useDialogBackdrop");
var _DialogRootContext = require("../Root/DialogRootContext");
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 *
 * Demos:
 *
 * - [Dialog](https://base-ui.netlify.app/components/react-dialog/)
 *
 * API:
 *
 * - [DialogBackdrop API](https://base-ui.netlify.app/components/react-dialog/#api-reference-DialogBackdrop)
 */
const DialogBackdrop = exports.DialogBackdrop = /*#__PURE__*/React.forwardRef(function DialogBackdrop(props, forwardedRef) {
  const {
    render,
    className,
    keepMounted = false,
    ...other
  } = props;
  const {
    open,
    modal,
    hasParentDialog,
    setBackdropPresent,
    animated
  } = (0, _DialogRootContext.useDialogRootContext)();
  const handleMount = React.useCallback(() => setBackdropPresent(true), [setBackdropPresent]);
  const handleUnmount = React.useCallback(() => setBackdropPresent(false), [setBackdropPresent]);
  const {
    getRootProps,
    mounted,
    transitionStatus
  } = (0, _useDialogBackdrop.useDialogBackdrop)({
    animated,
    open,
    ref: forwardedRef,
    onMount: handleMount,
    onUnmount: handleUnmount
  });
  const ownerState = React.useMemo(() => ({
    open,
    modal,
    transitionStatus
  }), [open, modal, transitionStatus]);
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    render: render ?? 'div',
    className,
    ownerState,
    propGetter: getRootProps,
    extraProps: other,
    customStyleHookMapping: {
      open: value => ({
        'data-state': value ? 'open' : 'closed'
      }),
      transitionStatus: value => {
        if (value === 'entering') {
          return {
            'data-entering': ''
          };
        }
        if (value === 'exiting') {
          return {
            'data-exiting': ''
          };
        }
        return null;
      }
    }
  });
  if (!mounted && !keepMounted) {
    return null;
  }
  if (hasParentDialog) {
    // no need to render nested backdrops
    return null;
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_react2.FloatingPortal, {
    children: renderElement()
  });
});
process.env.NODE_ENV !== "production" ? DialogBackdrop.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * If `true`, the backdrop element is kept in the DOM when closed.
   *
   * @default false
   */
  keepMounted: _propTypes.default.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func])
} : void 0;