"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DialogPopup = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _react2 = require("@floating-ui/react");
var _useDialogPopup = require("./useDialogPopup");
var _DialogRootContext = require("../Root/DialogRootContext");
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _proptypes = require("../../utils/proptypes");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 *
 * Demos:
 *
 * - [Dialog](https://base-ui.netlify.app/components/react-dialog/)
 *
 * API:
 *
 * - [DialogPopup API](https://base-ui.netlify.app/components/react-dialog/#api-reference-DialogPopup)
 */
const DialogPopup = exports.DialogPopup = /*#__PURE__*/React.forwardRef(function DialogPopup(props, forwardedRef) {
  const {
    className,
    container,
    id,
    keepMounted = false,
    render,
    ...other
  } = props;
  const rootContext = (0, _DialogRootContext.useDialogRootContext)();
  const {
    open,
    modal,
    nestedOpenDialogCount,
    dismissible
  } = rootContext;
  const {
    getRootProps,
    floatingContext,
    mounted,
    transitionStatus
  } = (0, _useDialogPopup.useDialogPopup)({
    id,
    ref: forwardedRef,
    isTopmost: nestedOpenDialogCount === 0,
    ...rootContext
  });
  const ownerState = {
    open,
    modal,
    nestedOpenDialogCount,
    transitionStatus
  };
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    render: render ?? 'div',
    className,
    ownerState,
    propGetter: getRootProps,
    extraProps: {
      ...other,
      style: {
        ...other.style,
        '--nested-dialogs': nestedOpenDialogCount
      }
    },
    customStyleHookMapping: {
      open: value => ({
        'data-state': value ? 'open' : 'closed'
      }),
      nestedOpenDialogCount: value => ({
        'data-nested-dialogs': value.toString()
      }),
      transitionStatus: value => {
        if (value === 'entering') {
          return {
            'data-entering': ''
          };
        }
        if (value === 'exiting') {
          return {
            'data-exiting': ''
          };
        }
        return null;
      }
    }
  });
  if (!keepMounted && !mounted) {
    return null;
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_react2.FloatingPortal, {
    root: container,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_react2.FloatingFocusManager, {
      context: floatingContext,
      modal: modal,
      disabled: !mounted,
      closeOnFocusOut: dismissible,
      children: renderElement()
    })
  });
});
process.env.NODE_ENV !== "production" ? DialogPopup.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * The container element to which the popup is appended to.
   */
  container: _propTypes.default /* @typescript-to-proptypes-ignore */.oneOfType([_proptypes.HTMLElementType, _proptypes.refType]),
  /**
   * @ignore
   */
  id: _propTypes.default.string,
  /**
   * If `true`, the dialog element is kept in the DOM when closed.
   *
   * @default false
   */
  keepMounted: _propTypes.default.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func]),
  /**
   * @ignore
   */
  style: _propTypes.default.object
} : void 0;