"use strict";
'use client';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDialogPopup = useDialogPopup;
var React = _interopRequireWildcard(require("react"));
var _react2 = require("@floating-ui/react");
var _useId = require("../../utils/useId");
var _useForkRef = require("../../utils/useForkRef");
var _mergeReactProps = require("../../utils/mergeReactProps");
var _useAnimatedElement = require("../../utils/useAnimatedElement");
var _useScrollLock = require("../../utils/useScrollLock");
var _useEnhancedEffect = require("../../utils/useEnhancedEffect");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function useDialogPopup(parameters) {
  const {
    animated,
    descriptionElementId,
    id: idParam,
    modal,
    onOpenChange,
    open,
    ref,
    setPopupElementId,
    dismissible,
    titleElementId,
    isTopmost
  } = parameters;
  const {
    refs,
    context,
    elements
  } = (0, _react2.useFloating)({
    open,
    onOpenChange
  });
  const popupRef = React.useRef(null);
  const dismiss = (0, _react2.useDismiss)(context, {
    outsidePressEvent: 'mousedown',
    outsidePress: isTopmost && dismissible,
    escapeKey: isTopmost
  });
  const {
    getFloatingProps
  } = (0, _react2.useInteractions)([dismiss]);
  const id = (0, _useId.useId)(idParam);
  const handleRef = (0, _useForkRef.useForkRef)(ref, popupRef, refs.setFloating);
  const {
    mounted,
    transitionStatus
  } = (0, _useAnimatedElement.useAnimatedElement)({
    open,
    ref: popupRef,
    enabled: animated
  });
  (0, _useScrollLock.useScrollLock)(modal && mounted, elements.floating);
  (0, _useEnhancedEffect.useEnhancedEffect)(() => {
    setPopupElementId(id);
    return () => {
      setPopupElementId(undefined);
    };
  }, [id, setPopupElementId]);
  const getRootProps = externalProps => (0, _mergeReactProps.mergeReactProps)(externalProps, {
    'aria-labelledby': titleElementId ?? undefined,
    'aria-describedby': descriptionElementId ?? undefined,
    'aria-hidden': !open || undefined,
    'aria-modal': open && modal ? true : undefined,
    role: 'dialog',
    tabIndex: -1,
    ...getFloatingProps(),
    id,
    ref: handleRef
  });
  return {
    floatingContext: context,
    getRootProps,
    mounted,
    transitionStatus
  };
}