"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FieldError = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _FieldRootContext = require("../Root/FieldRootContext");
var _useFieldError = require("./useFieldError");
var _constants = require("../utils/constants");
var _FormRootContext = require("../../Form/Root/FormRootContext");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Displays error messages for the field's control.
 *
 * Demos:
 *
 * - [Field](https://base-ui.netlify.app/components/react-field/)
 *
 * API:
 *
 * - [FieldError API](https://base-ui.netlify.app/components/react-field/#api-reference-FieldError)
 */
const FieldError = exports.FieldError = /*#__PURE__*/React.forwardRef(function FieldError(props, forwardedRef) {
  const {
    render,
    id,
    className,
    show,
    forceShow,
    ...otherProps
  } = props;
  const {
    validityData,
    ownerState,
    name
  } = (0, _FieldRootContext.useFieldRootContext)(false);
  const {
    errors
  } = (0, _FormRootContext.useFormRootContext)();
  const formError = name ? errors[name] : null;
  let rendered = false;
  if (formError || forceShow) {
    rendered = true;
  } else if (show) {
    rendered = Boolean(validityData.state[show]);
  } else if (forceShow == null) {
    rendered = validityData.state.valid === false;
  }
  const {
    getErrorProps
  } = (0, _useFieldError.useFieldError)({
    id,
    rendered,
    formError
  });
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    propGetter: getErrorProps,
    render: render ?? 'div',
    ref: forwardedRef,
    className,
    ownerState,
    extraProps: otherProps,
    customStyleHookMapping: _constants.STYLE_HOOK_MAPPING
  });
  if (!rendered) {
    return null;
  }
  return renderElement();
});
process.env.NODE_ENV !== "production" ? FieldError.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * Determines whether the error message should be shown regardless of the field's client validity.
   */
  forceShow: _propTypes.default.bool,
  /**
   * @ignore
   */
  id: _propTypes.default.string,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func]),
  /**
   * Determines whether the error message should be shown when it matches a given property of the
   * field's `ValidityState`.
   */
  show: _propTypes.default.oneOf(['badInput', 'customError', 'patternMismatch', 'rangeOverflow', 'rangeUnderflow', 'stepMismatch', 'tooLong', 'tooShort', 'typeMismatch', 'valid', 'valueMissing'])
} : void 0;