"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FormRoot = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _mergeReactProps = require("../../utils/mergeReactProps");
var _FormRootContext = require("./FormRootContext");
var _useEventCallback = require("../../utils/useEventCallback");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 *
 * Demos:
 *
 * - [Form](https://base-ui.netlify.app/components/react-form/)
 *
 * API:
 *
 * - [FormRoot API](https://base-ui.netlify.app/components/react-form/#api-reference-FormRoot)
 */const FormRoot = exports.FormRoot = /*#__PURE__*/React.forwardRef(function FormRoot(props, forwardedRef) {
  const {
    render,
    className,
    errors,
    onClearErrors: onClearErrorsProp,
    onSubmit: onSubmitProp,
    ...otherProps
  } = props;
  const formRef = React.useRef({
    fields: new Map()
  });
  const onSubmit = (0, _useEventCallback.useEventCallback)(onSubmitProp || (() => {}));
  const onClearErrors = (0, _useEventCallback.useEventCallback)(onClearErrorsProp || (() => {}));
  const getFormProps = React.useCallback((externalProps = {}) => (0, _mergeReactProps.mergeReactProps)(externalProps, {
    noValidate: true,
    onSubmit(event) {
      let values = Array.from(formRef.current.fields.values());

      // Async validation isn't supported to stop the submit event.
      values.forEach(field => {
        field.validate();
      });
      values = Array.from(formRef.current.fields.values());
      const invalidFields = values.filter(field => !field.validityData.state.valid);
      if (invalidFields.length) {
        event.preventDefault();
        invalidFields[0]?.controlRef.current?.focus();
      } else {
        onSubmit(event);
      }
    }
  }), [onSubmit]);
  React.useEffect(() => {
    const invalidFields = Array.from(formRef.current.fields.values()).filter(field => field.validityData.state.valid === false);
    if (invalidFields.length) {
      invalidFields[0]?.controlRef.current?.focus();
    }
  }, [errors]);
  const ownerState = React.useMemo(() => ({}), []);
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    propGetter: getFormProps,
    render: render ?? 'form',
    ref: forwardedRef,
    ownerState,
    className,
    extraProps: otherProps
  });
  const contextValue = React.useMemo(() => ({
    formRef,
    errors: errors ?? {},
    onClearErrors
  }), [formRef, errors, onClearErrors]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_FormRootContext.FormRootContext.Provider, {
    value: contextValue,
    children: renderElement()
  });
});
process.env.NODE_ENV !== "production" ? FormRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * Object of error messages with each key mapping to the `name` prop of a Field control, usually
   * from server-side validation.
   */
  errors: _propTypes.default.object,
  /**
   * Callback fired when the external server-side `error` messages should be cleared.
   */
  onClearErrors: _propTypes.default.func,
  /**
   * @ignore
   */
  onSubmit: _propTypes.default.func,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func])
} : void 0;