"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuArrow = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _useMenuArrow = require("./useMenuArrow");
var _MenuPositionerContext = require("../Positioner/MenuPositionerContext");
var _MenuRootContext = require("../Root/MenuRootContext");
var _commonStyleHooks = require("../utils/commonStyleHooks");
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _useForkRef = require("../../utils/useForkRef");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Renders an arrow that points to the center of the anchor element.
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuArrow API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuArrow)
 */
const MenuArrow = exports.MenuArrow = /*#__PURE__*/React.forwardRef(function MenuArrow(props, forwardedRef) {
  const {
    className,
    render,
    hideWhenUncentered = false,
    ...otherProps
  } = props;
  const {
    open
  } = (0, _MenuRootContext.useMenuRootContext)();
  const {
    arrowRef,
    side,
    alignment,
    arrowUncentered,
    arrowStyles
  } = (0, _MenuPositionerContext.useMenuPositionerContext)();
  const {
    getArrowProps
  } = (0, _useMenuArrow.useMenuArrow)({
    arrowStyles,
    hidden: hideWhenUncentered && arrowUncentered
  });
  const ownerState = React.useMemo(() => ({
    open,
    side,
    alignment,
    arrowUncentered
  }), [open, side, alignment, arrowUncentered]);
  const mergedRef = (0, _useForkRef.useForkRef)(arrowRef, forwardedRef);
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    propGetter: getArrowProps,
    render: render ?? 'div',
    className,
    ownerState,
    ref: mergedRef,
    extraProps: otherProps,
    customStyleHookMapping: _commonStyleHooks.commonStyleHooks
  });
  return renderElement();
});
process.env.NODE_ENV !== "production" ? MenuArrow.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * If `true`, the arrow is hidden when it can't point to the center of the anchor element.
   * @default false
   */
  hideWhenUncentered: _propTypes.default.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func])
} : void 0;