"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuPopup = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _react2 = require("@floating-ui/react");
var _useMenuPopup = require("./useMenuPopup");
var _MenuRootContext = require("../Root/MenuRootContext");
var _MenuPositionerContext = require("../Positioner/MenuPositionerContext");
var _commonStyleHooks = require("../utils/commonStyleHooks");
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _useForkRef = require("../../utils/useForkRef");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const customStyleHookMapping = {
  ..._commonStyleHooks.commonStyleHooks,
  entering(value) {
    return value ? {
      'data-menu-entering': ''
    } : null;
  },
  exiting(value) {
    return value ? {
      'data-menu-exiting': ''
    } : null;
  }
};

/**
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuPopup API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuPopup)
 */
const MenuPopup = exports.MenuPopup = /*#__PURE__*/React.forwardRef(function MenuPopup(props, forwardedRef) {
  const {
    render,
    className,
    ...other
  } = props;
  const {
    open,
    setOpen,
    popupRef,
    transitionStatus
  } = (0, _MenuRootContext.useMenuRootContext)();
  const {
    side,
    alignment
  } = (0, _MenuPositionerContext.useMenuPositionerContext)();
  const {
    events: menuEvents
  } = (0, _react2.useFloatingTree)();
  (0, _useMenuPopup.useMenuPopup)({
    setOpen,
    menuEvents
  });
  const mergedRef = (0, _useForkRef.useForkRef)(forwardedRef, popupRef);
  const ownerState = {
    entering: transitionStatus === 'entering',
    exiting: transitionStatus === 'exiting',
    side,
    alignment,
    open
  };
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    render: render || 'div',
    className,
    ownerState,
    extraProps: other,
    customStyleHookMapping,
    ref: mergedRef
  });
  return renderElement();
});
process.env.NODE_ENV !== "production" ? MenuPopup.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * The id of the popup element.
   */
  id: _propTypes.default.string,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func])
} : void 0;