"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuPositioner = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _react2 = require("@floating-ui/react");
var _MenuPositionerContext = require("./MenuPositionerContext");
var _MenuRootContext = require("../Root/MenuRootContext");
var _commonStyleHooks = require("../utils/commonStyleHooks");
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _useForkRef = require("../../utils/useForkRef");
var _useMenuPositioner = require("./useMenuPositioner");
var _proptypes = require("../../utils/proptypes");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Renders the element that positions the Menu popup.
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuPositioner API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuPositioner)
 */
const MenuPositioner = exports.MenuPositioner = /*#__PURE__*/React.forwardRef(function MenuPositioner(props, forwardedRef) {
  const {
    anchor,
    positionMethod = 'absolute',
    className,
    render,
    keepMounted = false,
    side = 'bottom',
    alignment = 'center',
    sideOffset = 0,
    alignmentOffset = 0,
    collisionBoundary = 'clippingAncestors',
    collisionPadding = 5,
    arrowPadding = 5,
    hideWhenDetached = false,
    sticky = false,
    container,
    ...otherProps
  } = props;
  const {
    open,
    floatingRootContext,
    getPositionerProps,
    setPositionerElement,
    nested,
    itemDomElements,
    itemLabels,
    triggerElement,
    mounted
  } = (0, _MenuRootContext.useMenuRootContext)();
  const nodeId = (0, _react2.useFloatingNodeId)();
  const positioner = (0, _useMenuPositioner.useMenuPositioner)({
    anchor: anchor || triggerElement,
    floatingRootContext,
    positionMethod,
    container,
    open,
    mounted,
    side,
    sideOffset,
    alignment,
    alignmentOffset,
    arrowPadding,
    collisionBoundary,
    collisionPadding,
    hideWhenDetached,
    sticky,
    nodeId
  });
  const ownerState = React.useMemo(() => ({
    open,
    side: positioner.side,
    alignment: positioner.alignment
  }), [open, positioner.side, positioner.alignment]);
  const contextValue = React.useMemo(() => ({
    side: positioner.side,
    alignment: positioner.alignment,
    arrowRef: positioner.arrowRef,
    arrowUncentered: positioner.arrowUncentered,
    arrowStyles: positioner.arrowStyles,
    floatingContext: positioner.floatingContext
  }), [positioner.side, positioner.alignment, positioner.arrowRef, positioner.arrowUncentered, positioner.arrowStyles, positioner.floatingContext]);
  const mergedRef = (0, _useForkRef.useForkRef)(forwardedRef, setPositionerElement);
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    propGetter: externalProps => positioner.getPositionerProps(getPositionerProps(externalProps)),
    render: render ?? 'div',
    className,
    ownerState,
    customStyleHookMapping: _commonStyleHooks.commonStyleHooks,
    ref: mergedRef,
    extraProps: otherProps
  });
  const shouldRender = keepMounted || mounted;
  if (!shouldRender) {
    return null;
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_MenuPositionerContext.MenuPositionerContext.Provider, {
    value: contextValue,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_react2.FloatingNode, {
      id: nodeId,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_react2.FloatingList, {
        elementsRef: itemDomElements,
        labelsRef: itemLabels,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_react2.FloatingPortal, {
          root: props.container,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_react2.FloatingFocusManager, {
            context: positioner.floatingContext,
            modal: false,
            initialFocus: nested ? -1 : 0,
            returnFocus: true,
            disabled: !mounted,
            children: renderElement()
          })
        })
      })
    })
  });
});
process.env.NODE_ENV !== "production" ? MenuPositioner.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * The alignment of the Menu element to the anchor element along its cross axis.
   * @default 'center'
   */
  alignment: _propTypes.default.oneOf(['center', 'end', 'start']),
  /**
   * The offset of the Menu element along its alignment axis.
   * @default 0
   */
  alignmentOffset: _propTypes.default.number,
  /**
   * The anchor element to which the Menu popup will be placed at.
   */
  anchor: _propTypes.default /* @typescript-to-proptypes-ignore */.oneOfType([_proptypes.HTMLElementType, _propTypes.default.object, _propTypes.default.func]),
  /**
   * Determines the padding between the arrow and the Menu popup's edges. Useful when the popover
   * popup has rounded corners via `border-radius`.
   * @default 5
   */
  arrowPadding: _propTypes.default.number,
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * The boundary that the Menu element should be constrained to.
   * @default 'clippingAncestors'
   */
  collisionBoundary: _propTypes.default /* @typescript-to-proptypes-ignore */.oneOfType([_proptypes.HTMLElementType, _propTypes.default.arrayOf(_proptypes.HTMLElementType), _propTypes.default.string, _propTypes.default.shape({
    height: _propTypes.default.number,
    width: _propTypes.default.number,
    x: _propTypes.default.number,
    y: _propTypes.default.number
  })]),
  /**
   * The padding of the collision boundary.
   * @default 5
   */
  collisionPadding: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.shape({
    bottom: _propTypes.default.number,
    left: _propTypes.default.number,
    right: _propTypes.default.number,
    top: _propTypes.default.number
  })]),
  /**
   * The container element to which the Menu popup will be appended to.
   */
  container: _propTypes.default /* @typescript-to-proptypes-ignore */.oneOfType([_proptypes.HTMLElementType, _propTypes.default.func]),
  /**
   * If `true`, the Menu will be hidden if it is detached from its anchor element due to
   * differing clipping contexts.
   * @default false
   */
  hideWhenDetached: _propTypes.default.bool,
  /**
   * Whether the menu popup remains mounted in the DOM while closed.
   * @default false
   */
  keepMounted: _propTypes.default.bool,
  /**
   * The CSS position strategy for positioning the Menu popup element.
   * @default 'absolute'
   */
  positionMethod: _propTypes.default.oneOf(['absolute', 'fixed']),
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func]),
  /**
   * The side of the anchor element that the Menu element should align to.
   * @default 'bottom'
   */
  side: _propTypes.default.oneOf(['bottom', 'left', 'right', 'top']),
  /**
   * The gap between the anchor element and the Menu element.
   * @default 0
   */
  sideOffset: _propTypes.default.number,
  /**
   * If `true`, allow the Menu to remain in stuck view while the anchor element is scrolled out
   * of view.
   * @default false
   */
  sticky: _propTypes.default.bool
} : void 0;