"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuRadioItem = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _react2 = require("@floating-ui/react");
var _useMenuRadioItem = require("./useMenuRadioItem");
var _MenuRootContext = require("../Root/MenuRootContext");
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _useId = require("../../utils/useId");
var _useForkRef = require("../../utils/useForkRef");
var _MenuRadioGroupContext = require("../RadioGroup/MenuRadioGroupContext");
var _MenuRadioItemContext = require("./MenuRadioItemContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const customStyleHookMapping = {
  checked: value => ({
    'data-radioitem': value ? 'checked' : 'unchecked'
  })
};
const InnerMenuRadioItem = /*#__PURE__*/React.memo(/*#__PURE__*/React.forwardRef(function InnerMenuItem(props, forwardedRef) {
  const {
    checked,
    setChecked,
    className,
    closeOnClick = false,
    disabled = false,
    highlighted,
    id,
    menuEvents,
    propGetter,
    render,
    treatMouseupAsClick,
    typingRef,
    ...other
  } = props;
  const {
    getRootProps
  } = (0, _useMenuRadioItem.useMenuRadioItem)({
    checked,
    setChecked,
    closeOnClick,
    disabled,
    highlighted,
    id,
    menuEvents,
    ref: forwardedRef,
    treatMouseupAsClick,
    typingRef
  });
  const ownerState = {
    disabled,
    highlighted,
    checked
  };
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    render: render || 'div',
    className,
    ownerState,
    propGetter: externalProps => propGetter(getRootProps(externalProps)),
    customStyleHookMapping,
    extraProps: other
  });
  return renderElement();
}));

/**
 * An unstyled menu item to be used within a Menu.
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuRadioItem API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuRadioItem)
 */
const MenuRadioItem = exports.MenuRadioItem = /*#__PURE__*/React.forwardRef(function MenuRadioItem(props, forwardedRef) {
  const {
    id: idProp,
    value,
    label,
    disabled = false,
    ...other
  } = props;
  const itemRef = React.useRef(null);
  const listItem = (0, _react2.useListItem)({
    label: label ?? itemRef.current?.innerText
  });
  const mergedRef = (0, _useForkRef.useForkRef)(forwardedRef, listItem.ref, itemRef);
  const {
    getItemProps,
    activeIndex,
    clickAndDragEnabled,
    typingRef
  } = (0, _MenuRootContext.useMenuRootContext)();
  const id = (0, _useId.useId)(idProp);
  const highlighted = listItem.index === activeIndex;
  const {
    events: menuEvents
  } = (0, _react2.useFloatingTree)();
  const {
    value: selectedValue,
    setValue: setSelectedValue
  } = (0, _MenuRadioGroupContext.useMenuRadioGroupContext)();

  // This wrapper component is used as a performance optimization.
  // MenuRadioItem reads the context and re-renders the actual MenuRadioItem
  // only when it needs to.

  const checked = selectedValue === value;
  const setChecked = React.useCallback(event => {
    setSelectedValue(value, event);
  }, [setSelectedValue, value]);
  const contextValue = React.useMemo(() => ({
    checked,
    highlighted,
    disabled
  }), [checked, highlighted, disabled]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_MenuRadioItemContext.MenuRadioItemContext.Provider, {
    value: contextValue,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(InnerMenuRadioItem, {
      ...other,
      id: id,
      ref: mergedRef,
      highlighted: highlighted,
      menuEvents: menuEvents,
      propGetter: getItemProps,
      treatMouseupAsClick: clickAndDragEnabled,
      checked: selectedValue === value,
      setChecked: setChecked,
      typingRef: typingRef
    })
  });
});
process.env.NODE_ENV !== "production" ? MenuRadioItem.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * If `true`, the menu will close when the menu item is clicked.
   *
   * @default true
   */
  closeOnClick: _propTypes.default.bool,
  /**
   * If `true`, the menu item will be disabled.
   * @default false
   */
  disabled: _propTypes.default.bool,
  /**
   * The id of the menu item.
   */
  id: _propTypes.default.string,
  /**
   * A text representation of the menu item's content.
   * Used for keyboard text navigation matching.
   */
  label: _propTypes.default.string,
  /**
   * The click handler for the menu item.
   */
  onClick: _propTypes.default.func,
  /**
   * Value of the radio item.
   * This is the value that will be set in the MenuRadioGroup when the item is selected.
   */
  value: _propTypes.default.any.isRequired
} : void 0;