"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuRoot = MenuRoot;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _react2 = require("@floating-ui/react");
var _MenuRootContext = require("./MenuRootContext");
var _useMenuRoot = require("./useMenuRoot");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [MenuRoot API](https://base-ui.netlify.app/components/react-menu/#api-reference-MenuRoot)
 */function MenuRoot(props) {
  const {
    animated = true,
    children,
    defaultOpen = false,
    dir: direction = 'ltr',
    disabled = false,
    closeParentOnEsc = true,
    loop = true,
    onOpenChange,
    open,
    orientation = 'vertical',
    delay = 100,
    openOnHover: openOnHoverProp
  } = props;
  const parentContext = (0, _MenuRootContext.useMenuRootContext)(true);
  const nested = parentContext != null;
  const openOnHover = openOnHoverProp ?? nested;
  const typingRef = React.useRef(false);
  const onTypingChange = React.useCallback(nextTyping => {
    typingRef.current = nextTyping;
  }, []);
  const menuRoot = (0, _useMenuRoot.useMenuRoot)({
    animated,
    direction,
    disabled,
    closeParentOnEsc,
    onOpenChange,
    loop,
    defaultOpen,
    open,
    orientation,
    nested,
    openOnHover,
    delay,
    onTypingChange
  });
  const [localClickAndDragEnabled, setLocalClickAndDragEnabled] = React.useState(false);
  let clickAndDragEnabled = localClickAndDragEnabled;
  let setClickAndDragEnabled = setLocalClickAndDragEnabled;
  if (parentContext != null) {
    clickAndDragEnabled = parentContext.clickAndDragEnabled;
    setClickAndDragEnabled = parentContext.setClickAndDragEnabled;
  }
  const context = React.useMemo(() => ({
    ...menuRoot,
    nested,
    parentContext,
    disabled,
    clickAndDragEnabled,
    setClickAndDragEnabled,
    typingRef
  }), [menuRoot, nested, parentContext, disabled, clickAndDragEnabled, setClickAndDragEnabled]);
  if (!nested) {
    // set up a FloatingTree to provide the context to nested menus
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_react2.FloatingTree, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_MenuRootContext.MenuRootContext.Provider, {
        value: context,
        children: children
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_MenuRootContext.MenuRootContext.Provider, {
    value: context,
    children: children
  });
}
process.env.NODE_ENV !== "production" ? MenuRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * If `true`, the Menu supports CSS-based animations and transitions.
   * It is kept in the DOM until the animation completes.
   *
   * @default true
   */
  animated: _propTypes.default.bool,
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Determines if pressing the Esc key closes the parent menus.
   * This is only applicable for nested menus.
   *
   * If set to `false` pressing Esc closes only the current menu.
   *
   * @default true
   */
  closeParentOnEsc: _propTypes.default.bool,
  /**
   * If `true`, the Menu is initially open.
   *
   * @default false
   */
  defaultOpen: _propTypes.default.bool,
  /**
   * The delay in milliseconds until the menu popup is opened when `openOnHover` is `true`.
   *
   * @default 100
   */
  delay: _propTypes.default.number,
  /**
   * The direction of the Menu (left-to-right or right-to-left).
   *
   * @default 'ltr'
   */
  dir: _propTypes.default.oneOf(['ltr', 'rtl']),
  /**
   * If `true`, the Menu is disabled.
   *
   * @default false
   */
  disabled: _propTypes.default.bool,
  /**
   * If `true`, using keyboard navigation will wrap focus to the other end of the list once the end is reached.
   * @default true
   */
  loop: _propTypes.default.bool,
  /**
   * Callback fired when the component requests to be opened or closed.
   */
  onOpenChange: _propTypes.default.func,
  /**
   * Allows to control whether the dropdown is open.
   * This is a controlled counterpart of `defaultOpen`.
   */
  open: _propTypes.default.bool,
  /**
   * Whether the menu popup opens when the trigger is hovered after the provided `delay`.
   * By default, `openOnHover` is set to `true` for nested menus.
   */
  openOnHover: _propTypes.default.bool,
  /**
   * The orientation of the Menu (horizontal or vertical).
   *
   * @default 'vertical'
   */
  orientation: _propTypes.default.oneOf(['horizontal', 'vertical'])
} : void 0;