"use strict";
'use client';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useMenuRoot = useMenuRoot;
var React = _interopRequireWildcard(require("react"));
var _react2 = require("@floating-ui/react");
var _mergeReactProps = require("../../utils/mergeReactProps");
var _useTransitionStatus = require("../../utils/useTransitionStatus");
var _useEventCallback = require("../../utils/useEventCallback");
var _useAnimationsFinished = require("../../utils/useAnimationsFinished");
var _useControlled = require("../../utils/useControlled");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const EMPTY_ARRAY = [];
function useMenuRoot(parameters) {
  const {
    animated,
    open: openParam,
    defaultOpen,
    onOpenChange,
    orientation,
    direction,
    disabled,
    nested,
    closeParentOnEsc,
    loop,
    delay,
    openOnHover,
    onTypingChange
  } = parameters;
  const [triggerElement, setTriggerElement] = React.useState(null);
  const [positionerElement, setPositionerElement] = React.useState(null);
  const popupRef = React.useRef(null);
  const [hoverEnabled, setHoverEnabled] = React.useState(true);
  const [activeIndex, setActiveIndex] = React.useState(null);
  const [open, setOpenUnwrapped] = (0, _useControlled.useControlled)({
    controlled: openParam,
    default: defaultOpen,
    name: 'useMenuRoot',
    state: 'open'
  });
  const {
    mounted,
    setMounted,
    transitionStatus
  } = (0, _useTransitionStatus.useTransitionStatus)(open, animated);
  const runOnceAnimationsFinish = (0, _useAnimationsFinished.useAnimationsFinished)(popupRef);
  const setOpen = (0, _useEventCallback.useEventCallback)((nextOpen, event) => {
    onOpenChange?.(nextOpen, event);
    setOpenUnwrapped(nextOpen);
    if (!nextOpen) {
      if (animated) {
        runOnceAnimationsFinish(() => setMounted(false));
      } else {
        setMounted(false);
      }
    }
  });
  const floatingRootContext = (0, _react2.useFloatingRootContext)({
    elements: {
      reference: triggerElement,
      floating: positionerElement
    },
    open,
    onOpenChange: setOpen
  });
  const hover = (0, _react2.useHover)(floatingRootContext, {
    enabled: hoverEnabled && openOnHover && !disabled,
    handleClose: (0, _react2.safePolygon)({
      blockPointerEvents: true
    }),
    mouseOnly: true,
    delay: {
      open: delay
    }
  });
  const click = (0, _react2.useClick)(floatingRootContext, {
    enabled: !disabled,
    event: 'mousedown',
    toggle: !nested,
    ignoreMouse: nested
  });
  const dismiss = (0, _react2.useDismiss)(floatingRootContext, {
    bubbles: closeParentOnEsc
  });
  const role = (0, _react2.useRole)(floatingRootContext, {
    role: 'menu'
  });
  const itemDomElements = React.useRef([]);
  const itemLabels = React.useRef([]);
  const listNavigation = (0, _react2.useListNavigation)(floatingRootContext, {
    enabled: !disabled,
    listRef: itemDomElements,
    activeIndex,
    nested,
    loop,
    orientation,
    rtl: direction === 'rtl',
    disabledIndices: EMPTY_ARRAY,
    onNavigate: setActiveIndex
  });
  const typeahead = (0, _react2.useTypeahead)(floatingRootContext, {
    listRef: itemLabels,
    activeIndex,
    resetMs: 350,
    onMatch: index => {
      if (open && index !== activeIndex) {
        setActiveIndex(index);
      }
    },
    onTypingChange
  });
  const {
    getReferenceProps,
    getFloatingProps,
    getItemProps
  } = (0, _react2.useInteractions)([hover, click, dismiss, role, listNavigation, typeahead]);
  const getTriggerProps = React.useCallback(externalProps => getReferenceProps((0, _mergeReactProps.mergeReactProps)(externalProps, {
    onMouseEnter: () => {
      setHoverEnabled(true);
    }
  })), [getReferenceProps]);
  const getPositionerProps = React.useCallback(externalProps => getFloatingProps((0, _mergeReactProps.mergeReactProps)(externalProps, {
    onMouseEnter: () => {
      setHoverEnabled(false);
    }
  })), [getFloatingProps]);
  return React.useMemo(() => ({
    activeIndex,
    floatingRootContext,
    triggerElement,
    setTriggerElement,
    getTriggerProps,
    setPositionerElement,
    getPositionerProps,
    getItemProps,
    itemDomElements,
    itemLabels,
    mounted,
    transitionStatus,
    popupRef,
    open,
    setOpen
  }), [activeIndex, floatingRootContext, triggerElement, getTriggerProps, getPositionerProps, getItemProps, itemDomElements, itemLabels, mounted, transitionStatus, open, setOpen]);
}