"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SubmenuTrigger = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _react2 = require("@floating-ui/react");
var _MenuRootContext = require("../Root/MenuRootContext");
var _commonStyleHooks = require("../utils/commonStyleHooks");
var _useId = require("../../utils/useId");
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _useSubmenuTrigger = require("./useSubmenuTrigger");
var _useForkRef = require("../../utils/useForkRef");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 *
 * Demos:
 *
 * - [Menu](https://base-ui.netlify.app/components/react-menu/)
 *
 * API:
 *
 * - [SubmenuTrigger API](https://base-ui.netlify.app/components/react-menu/#api-reference-SubmenuTrigger)
 */
const SubmenuTrigger = exports.SubmenuTrigger = /*#__PURE__*/React.forwardRef(function SubmenuTriggerComponent(props, forwardedRef) {
  const {
    render,
    className,
    disabled = false,
    label,
    id: idProp,
    ...other
  } = props;
  const id = (0, _useId.useId)(idProp);
  const {
    getTriggerProps,
    parentContext,
    setTriggerElement,
    clickAndDragEnabled,
    open,
    typingRef
  } = (0, _MenuRootContext.useMenuRootContext)();
  if (parentContext === null) {
    throw new Error('Base UI: ItemTrigger must be placed in a nested Menu.');
  }
  const {
    activeIndex,
    getItemProps
  } = parentContext;
  const item = (0, _react2.useListItem)();
  const highlighted = activeIndex === item.index;
  const mergedRef = (0, _useForkRef.useForkRef)(forwardedRef, item.ref);
  const {
    events: menuEvents
  } = (0, _react2.useFloatingTree)();
  const {
    getRootProps
  } = (0, _useSubmenuTrigger.useSubmenuTrigger)({
    id,
    highlighted,
    ref: mergedRef,
    disabled,
    menuEvents,
    setTriggerElement,
    treatMouseupAsClick: clickAndDragEnabled,
    typingRef
  });
  const ownerState = {
    disabled,
    highlighted,
    open
  };
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    render: render || 'div',
    className,
    ownerState,
    propGetter: externalProps => getTriggerProps(getItemProps(getRootProps(externalProps))),
    customStyleHookMapping: _commonStyleHooks.commonStyleHooks,
    extraProps: other
  });
  return renderElement();
});
process.env.NODE_ENV !== "production" ? SubmenuTrigger.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * If `true`, the menu item will be disabled.
   * @default false
   */
  disabled: _propTypes.default.bool,
  /**
   * @ignore
   */
  id: _propTypes.default.string,
  /**
   * A text representation of the menu item's content.
   * Used for keyboard text navigation matching.
   */
  label: _propTypes.default.string,
  /**
   * @ignore
   */
  onClick: _propTypes.default.func,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func])
} : void 0;