"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NumberFieldRoot = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _NumberFieldContext = require("./NumberFieldContext");
var _useNumberFieldRoot = require("./useNumberFieldRoot");
var _FieldRootContext = require("../../Field/Root/FieldRootContext");
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * The foundation for building custom-styled number fields.
 *
 * Demos:
 *
 * - [Number Field](https://base-ui.netlify.app/components/react-number-field/)
 *
 * API:
 *
 * - [NumberFieldRoot API](https://base-ui.netlify.app/components/react-number-field/#api-reference-NumberFieldRoot)
 */
const NumberFieldRoot = exports.NumberFieldRoot = /*#__PURE__*/React.forwardRef(function NumberFieldRoot(props, forwardedRef) {
  const {
    id,
    min,
    max,
    smallStep,
    step,
    largeStep,
    autoFocus,
    required = false,
    disabled: disabledProp = false,
    invalid = false,
    readOnly = false,
    name,
    defaultValue,
    value,
    onValueChange,
    allowWheelScrub,
    format,
    render,
    className,
    ...otherProps
  } = props;
  const numberField = (0, _useNumberFieldRoot.useNumberFieldRoot)(props);
  const {
    ownerState: fieldOwnerState,
    disabled: fieldDisabled
  } = (0, _FieldRootContext.useFieldRootContext)();
  const disabled = fieldDisabled || disabledProp;
  const ownerState = React.useMemo(() => ({
    ...fieldOwnerState,
    disabled,
    invalid,
    readOnly,
    required,
    value: numberField.value,
    inputValue: numberField.inputValue,
    scrubbing: numberField.isScrubbing
  }), [fieldOwnerState, disabled, invalid, readOnly, required, numberField.value, numberField.inputValue, numberField.isScrubbing]);
  const contextValue = React.useMemo(() => ({
    ...numberField,
    ownerState
  }), [numberField, ownerState]);
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    ref: forwardedRef,
    render: render ?? 'div',
    ownerState,
    className,
    extraProps: otherProps
  });
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_NumberFieldContext.NumberFieldContext.Provider, {
    value: contextValue,
    children: renderElement()
  });
});
process.env.NODE_ENV !== "production" ? NumberFieldRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * Whether to allow the user to scrub the input value with the mouse wheel while focused and
   * hovering over the input.
   * @default false
   */
  allowWheelScrub: _propTypes.default.bool,
  /**
   * If `true`, the input element is focused on mount.
   * @default false
   */
  autoFocus: _propTypes.default.bool,
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * The default value of the input element. Use when the component is not controlled.
   */
  defaultValue: _propTypes.default.number,
  /**
   * If `true`, the input element is disabled.
   * @default false
   */
  disabled: _propTypes.default.bool,
  /**
   * Options to format the input value.
   */
  format: _propTypes.default.shape({
    compactDisplay: _propTypes.default.oneOf(['long', 'short']),
    currency: _propTypes.default.string,
    currencyDisplay: _propTypes.default.oneOf(['code', 'name', 'narrowSymbol', 'symbol']),
    currencySign: _propTypes.default.oneOf(['accounting', 'standard']),
    localeMatcher: _propTypes.default.oneOf(['best fit', 'lookup']),
    maximumFractionDigits: _propTypes.default.number,
    maximumSignificantDigits: _propTypes.default.number,
    minimumFractionDigits: _propTypes.default.number,
    minimumIntegerDigits: _propTypes.default.number,
    minimumSignificantDigits: _propTypes.default.number,
    notation: _propTypes.default.oneOf(['compact', 'engineering', 'scientific', 'standard']),
    numberingSystem: _propTypes.default.string,
    signDisplay: _propTypes.default.oneOf(['always', 'auto', 'exceptZero', 'never']),
    style: _propTypes.default.oneOf(['currency', 'decimal', 'percent', 'unit']),
    unit: _propTypes.default.string,
    unitDisplay: _propTypes.default.oneOf(['long', 'narrow', 'short']),
    useGrouping: _propTypes.default.bool
  }),
  /**
   * The id of the input element.
   */
  id: _propTypes.default.string,
  /**
   * If `true`, the input element is invalid.
   * @default false
   */
  invalid: _propTypes.default.bool,
  /**
   * The large step value of the input element when incrementing while the shift key is held. Snaps
   * to multiples of this value.
   * @default 10
   */
  largeStep: _propTypes.default.number,
  /**
   * The maximum value of the input element.
   */
  max: _propTypes.default.number,
  /**
   * The minimum value of the input element.
   */
  min: _propTypes.default.number,
  /**
   * The name of the input element.
   */
  name: _propTypes.default.string,
  /**
   * Callback fired when the number value changes.
   * @param {number | null} value The new value.
   * @param {Event} event The event that triggered the change.
   */
  onValueChange: _propTypes.default.func,
  /**
   * If `true`, the input element is read only.
   * @default false
   */
  readOnly: _propTypes.default.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func]),
  /**
   * If `true`, the input element is required.
   * @default false
   */
  required: _propTypes.default.bool,
  /**
   * The small step value of the input element when incrementing while the meta key is held. Snaps
   * to multiples of this value.
   * @default 0.1
   */
  smallStep: _propTypes.default.number,
  /**
   * The step value of the input element when incrementing, decrementing, or scrubbing. It will snap
   * to multiples of this value. When unspecified, decimal values are allowed, but the stepper
   * buttons will increment or decrement by `1`.
   */
  step: _propTypes.default.number,
  /**
   * The raw number value of the input element.
   */
  value: _propTypes.default.number
} : void 0;