"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PreviewCardRoot = PreviewCardRoot;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _PreviewCardContext = require("./PreviewCardContext");
var _usePreviewCardRoot = require("./usePreviewCardRoot");
var _constants = require("../utils/constants");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 *
 * Demos:
 *
 * - [Preview Card](https://base-ui.netlify.app/components/react-preview-card/)
 *
 * API:
 *
 * - [PreviewCardRoot API](https://base-ui.netlify.app/components/react-preview-card/#api-reference-PreviewCardRoot)
 */function PreviewCardRoot(props) {
  const {
    delayType = 'rest',
    delay,
    closeDelay,
    animated = true
  } = props;
  const delayWithDefault = delay ?? _constants.OPEN_DELAY;
  const closeDelayWithDefault = closeDelay ?? _constants.CLOSE_DELAY;
  const {
    open,
    setOpen,
    mounted,
    setMounted,
    triggerElement,
    setTriggerElement,
    positionerElement,
    setPositionerElement,
    popupRef,
    instantType,
    getRootTriggerProps,
    getRootPopupProps,
    floatingRootContext,
    transitionStatus
  } = (0, _usePreviewCardRoot.usePreviewCardRoot)({
    animated,
    delay,
    delayType,
    closeDelay,
    open: props.open,
    onOpenChange: props.onOpenChange,
    defaultOpen: props.defaultOpen
  });
  const contextValue = React.useMemo(() => ({
    delay: delayWithDefault,
    delayType,
    closeDelay: closeDelayWithDefault,
    open,
    setOpen,
    triggerElement,
    setTriggerElement,
    positionerElement,
    setPositionerElement,
    popupRef,
    mounted,
    setMounted,
    instantType,
    getRootTriggerProps,
    getRootPopupProps,
    floatingRootContext,
    transitionStatus
  }), [delayWithDefault, delayType, closeDelayWithDefault, open, setOpen, triggerElement, setTriggerElement, positionerElement, setPositionerElement, popupRef, mounted, setMounted, instantType, getRootTriggerProps, getRootPopupProps, floatingRootContext, transitionStatus]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_PreviewCardContext.PreviewCardRootContext.Provider, {
    value: contextValue,
    children: props.children
  });
}
process.env.NODE_ENV !== "production" ? PreviewCardRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * Whether the preview card can animate, adding animation-related attributes and allowing for exit
   * animations to play. Useful to disable in tests to remove async behavior.
   * @default true
   */
  animated: _propTypes.default.bool,
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * The delay in milliseconds until the preview card popup is closed when `openOnHover` is `true`.
   * @default 300
   */
  closeDelay: _propTypes.default.number,
  /**
   * Whether the preview card popup is open by default. Use when uncontrolled.
   * @default false
   */
  defaultOpen: _propTypes.default.bool,
  /**
   * The delay in milliseconds until the preview card popup is opened when `openOnHover` is `true`.
   * @default 600
   */
  delay: _propTypes.default.number,
  /**
   * The delay type to use when the preview card is triggered by hover. `rest` means the `delay`
   * represents how long the user's cursor must rest on the trigger before the preview card popup is
   * opened. `hover` means the `delay` represents how long to wait as soon as the user's cursor has
   * entered the trigger.
   * @default 'rest'
   */
  delayType: _propTypes.default.oneOf(['hover', 'rest']),
  /**
   * Callback fired when the preview card popup is requested to be opened or closed. Use when
   * controlled.
   */
  onOpenChange: _propTypes.default.func,
  /**
   * Whether the preview card popup is open. Use when controlled.
   * @default false
   */
  open: _propTypes.default.bool
} : void 0;