"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RadioGroupRoot = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _CompositeRoot = require("../../Composite/Root/CompositeRoot");
var _useComponentRenderer = require("../../utils/useComponentRenderer");
var _useEventCallback = require("../../utils/useEventCallback");
var _useRadioGroupRoot = require("./useRadioGroupRoot");
var _RadioGroupRootContext = require("./RadioGroupRootContext");
var _FieldRootContext = require("../../Field/Root/FieldRootContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 *
 * Demos:
 *
 * - [Radio Group](https://base-ui.netlify.app/components/react-radio-group/)
 *
 * API:
 *
 * - [RadioGroupRoot API](https://base-ui.netlify.app/components/react-radio-group/#api-reference-RadioGroupRoot)
 */const RadioGroupRoot = exports.RadioGroupRoot = /*#__PURE__*/React.forwardRef(function RadioGroupRoot(props, forwardedRef) {
  const {
    render,
    className,
    disabled: disabledProp,
    readOnly,
    required,
    onValueChange: onValueChangeProp,
    name,
    ...otherProps
  } = props;
  const {
    getRootProps,
    getInputProps,
    checkedValue,
    setCheckedValue,
    touched,
    setTouched
  } = (0, _useRadioGroupRoot.useRadioGroupRoot)(props);
  const {
    ownerState: fieldOwnerState,
    disabled: fieldDisabled
  } = (0, _FieldRootContext.useFieldRootContext)();
  const disabled = fieldDisabled || disabledProp;
  const onValueChange = (0, _useEventCallback.useEventCallback)(onValueChangeProp ?? (() => {}));
  const ownerState = React.useMemo(() => ({
    ...fieldOwnerState,
    disabled: disabled ?? false,
    required: required ?? false,
    readOnly: readOnly ?? false
  }), [fieldOwnerState, disabled, readOnly, required]);
  const contextValue = React.useMemo(() => ({
    checkedValue,
    setCheckedValue,
    onValueChange,
    disabled,
    readOnly,
    required,
    touched,
    setTouched
  }), [checkedValue, setCheckedValue, onValueChange, disabled, readOnly, required, touched, setTouched]);
  const {
    renderElement
  } = (0, _useComponentRenderer.useComponentRenderer)({
    propGetter: getRootProps,
    render: render ?? 'div',
    ref: forwardedRef,
    className,
    ownerState,
    extraProps: otherProps
  });
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_RadioGroupRootContext.RadioGroupRootContext.Provider, {
    value: contextValue,
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_CompositeRoot.CompositeRoot, {
      render: renderElement()
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)("input", {
      ...getInputProps()
    })]
  });
});
process.env.NODE_ENV !== "production" ? RadioGroupRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * The default value of the selected radio button. Use when uncontrolled.
   */
  defaultValue: _propTypes.default.any,
  /**
   * Determines if the radio group is disabled.
   * @default false
   */
  disabled: _propTypes.default.bool,
  /**
   * The name of the radio group submitted with the form data.
   */
  name: _propTypes.default.string,
  /**
   * Callback fired when the value changes.
   */
  onValueChange: _propTypes.default.func,
  /**
   * Determines if the radio group is readonly.
   * @default false
   */
  readOnly: _propTypes.default.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func]),
  /**
   * Determines if the radio group is required.
   * @default false
   */
  required: _propTypes.default.bool,
  /**
   * The value of the selected radio button. Use when controlled.
   */
  value: _propTypes.default.any
} : void 0;