"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SwitchRoot = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _refType = _interopRequireDefault(require("@mui/utils/refType"));
var _useSwitchRoot = require("./useSwitchRoot");
var _SwitchContext = require("./SwitchContext");
var _resolveClassName = require("../../utils/resolveClassName");
var _useSwitchStyleHooks = require("./useSwitchStyleHooks");
var _evaluateRenderProp = require("../../utils/evaluateRenderProp");
var _useRenderPropForkRef = require("../../utils/useRenderPropForkRef");
var _FieldRootContext = require("../../Field/Root/FieldRootContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function defaultRender(props) {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)("button", {
    type: "button",
    ...props
  });
}

/**
 * The foundation for building custom-styled switches.
 *
 * Demos:
 *
 * - [Switch](https://base-ui.netlify.app/components/react-switch/)
 *
 * API:
 *
 * - [SwitchRoot API](https://base-ui.netlify.app/components/react-switch/#api-reference-SwitchRoot)
 */
const SwitchRoot = exports.SwitchRoot = /*#__PURE__*/React.forwardRef(function SwitchRoot(props, forwardedRef) {
  const {
    checked: checkedProp,
    className: classNameProp,
    defaultChecked,
    inputRef,
    onCheckedChange,
    readOnly = false,
    required = false,
    disabled: disabledProp = false,
    render: renderProp,
    ...other
  } = props;
  const render = renderProp ?? defaultRender;
  const {
    getInputProps,
    getButtonProps,
    checked
  } = (0, _useSwitchRoot.useSwitchRoot)(props);
  const {
    ownerState: fieldOwnerState,
    disabled: fieldDisabled
  } = (0, _FieldRootContext.useFieldRootContext)();
  const disabled = fieldDisabled || disabledProp;
  const ownerState = React.useMemo(() => ({
    ...fieldOwnerState,
    checked,
    disabled,
    readOnly,
    required
  }), [fieldOwnerState, checked, disabled, readOnly, required]);
  const className = (0, _resolveClassName.resolveClassName)(classNameProp, ownerState);
  const styleHooks = (0, _useSwitchStyleHooks.useSwitchStyleHooks)(ownerState);
  const mergedRef = (0, _useRenderPropForkRef.useRenderPropForkRef)(render, forwardedRef);
  const buttonProps = {
    className,
    ref: mergedRef,
    ...styleHooks,
    ...other
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_SwitchContext.SwitchContext.Provider, {
    value: ownerState,
    children: [(0, _evaluateRenderProp.evaluateRenderProp)(render, getButtonProps(buttonProps), ownerState), !checked && props.name && /*#__PURE__*/(0, _jsxRuntime.jsx)("input", {
      type: "hidden",
      name: props.name,
      value: "off"
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)("input", {
      ...getInputProps()
    })]
  });
});
process.env.NODE_ENV !== "production" ? SwitchRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * If `true`, the switch is checked.
   */
  checked: _propTypes.default.bool,
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * The default checked state. Use when the component is not controlled.
   */
  defaultChecked: _propTypes.default.bool,
  /**
   * If `true`, the component is disabled and can't be interacted with.
   *
   * @default false
   */
  disabled: _propTypes.default.bool,
  /**
   * The id of the switch element.
   */
  id: _propTypes.default.string,
  /**
   * Ref to the underlying input element.
   */
  inputRef: _refType.default,
  /**
   * Name of the underlying input element.
   */
  name: _propTypes.default.string,
  /**
   * Callback fired when the checked state is changed.
   *
   * @param {boolean} checked The new checked state.
   * @param {React.ChangeEvent<HTMLInputElement>} event The event source of the callback.
   */
  onCheckedChange: _propTypes.default.func,
  /**
   * If `true`, the component is read-only.
   * Functionally, this is equivalent to being disabled, but the assistive technologies will announce this differently.
   *
   * @default false
   */
  readOnly: _propTypes.default.bool,
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func]),
  /**
   * If `true`, the switch must be checked for the browser validation to pass.
   *
   * @default false
   */
  required: _propTypes.default.bool
} : void 0;