"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SwitchThumb = void 0;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _SwitchContext = require("../Root/SwitchContext");
var _useSwitchStyleHooks = require("../Root/useSwitchStyleHooks");
var _resolveClassName = require("../../utils/resolveClassName");
var _evaluateRenderProp = require("../../utils/evaluateRenderProp");
var _useRenderPropForkRef = require("../../utils/useRenderPropForkRef");
var _FieldRootContext = require("../../Field/Root/FieldRootContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function defaultRender(props) {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
    ...props
  });
}

/**
 *
 * Demos:
 *
 * - [Switch](https://base-ui.netlify.app/components/react-switch/)
 *
 * API:
 *
 * - [SwitchThumb API](https://base-ui.netlify.app/components/react-switch/#api-reference-SwitchThumb)
 */
const SwitchThumb = exports.SwitchThumb = /*#__PURE__*/React.forwardRef(function SwitchThumb(props, forwardedRef) {
  const {
    render: renderProp,
    className: classNameProp,
    ...other
  } = props;
  const render = renderProp ?? defaultRender;
  const {
    ownerState: fieldOwnerState
  } = (0, _FieldRootContext.useFieldRootContext)();
  const ownerState = React.useContext(_SwitchContext.SwitchContext);
  if (ownerState === null) {
    throw new Error('Base UI: Switch.Thumb is not placed inside the Switch component.');
  }
  const extendedOwnerState = {
    ...fieldOwnerState,
    ...ownerState
  };
  const className = (0, _resolveClassName.resolveClassName)(classNameProp, extendedOwnerState);
  const styleHooks = (0, _useSwitchStyleHooks.useSwitchStyleHooks)(extendedOwnerState);
  const mergedRef = (0, _useRenderPropForkRef.useRenderPropForkRef)(render, forwardedRef);
  const elementProps = {
    className,
    ref: mergedRef,
    ...styleHooks,
    ...other
  };
  return (0, _evaluateRenderProp.evaluateRenderProp)(render, elementProps, ownerState);
});
process.env.NODE_ENV !== "production" ? SwitchThumb.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * Class names applied to the element or a function that returns them based on the component's state.
   */
  className: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string]),
  /**
   * A function to customize rendering of the component.
   */
  render: _propTypes.default.oneOfType([_propTypes.default.element, _propTypes.default.func])
} : void 0;