"use strict";
'use client';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTabsRoot = useTabsRoot;
var React = _interopRequireWildcard(require("react"));
var _useCompound = require("../../useCompound");
var _mergeReactProps = require("../../utils/mergeReactProps");
var _useControlled = require("../../utils/useControlled");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function useTabsRoot(parameters) {
  const {
    value: valueProp,
    defaultValue,
    onValueChange,
    orientation = 'horizontal',
    direction = 'ltr'
  } = parameters;
  const [value, setValue] = (0, _useControlled.useControlled)({
    controlled: valueProp,
    default: defaultValue,
    name: 'Tabs',
    state: 'value'
  });
  const [tabActivationDirection, setTabActivationDirection] = React.useState('none');
  const onSelected = React.useCallback((event, newValue, activationDirection) => {
    setValue(newValue);
    setTabActivationDirection(activationDirection);
    onValueChange?.(newValue, event);
  }, [onValueChange, setValue]);
  const {
    subitems: tabPanels,
    contextValue: compoundComponentContextValue
  } = (0, _useCompound.useCompoundParent)();
  const tabIdLookup = React.useRef(() => undefined);
  const getTabPanelId = React.useCallback(tabValue => {
    return tabPanels.get(tabValue)?.id;
  }, [tabPanels]);
  const getTabId = React.useCallback(tabPanelId => {
    return tabIdLookup.current(tabPanelId);
  }, []);
  const registerTabIdLookup = React.useCallback(lookupFunction => {
    tabIdLookup.current = lookupFunction;
  }, []);
  const getRootProps = React.useCallback((otherProps = {}) => (0, _mergeReactProps.mergeReactProps)(otherProps, {
    dir: direction
  }), [direction]);
  return {
    contextValue: {
      direction,
      getTabId,
      getTabPanelId,
      onSelected,
      orientation,
      registerTabIdLookup,
      value,
      tabActivationDirection,
      ...compoundComponentContextValue
    },
    getRootProps,
    tabActivationDirection
  };
}