"use strict";
'use client';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTab = useTab;
var React = _interopRequireWildcard(require("react"));
var _TabsContext = require("../Root/TabsContext");
var _useCompound = require("../../useCompound");
var _useList = require("../../useList");
var _useButton = require("../../useButton");
var _useId = require("../../utils/useId");
var _useForkRef = require("../../utils/useForkRef");
var _mergeReactProps = require("../../utils/mergeReactProps");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function tabValueGenerator(otherTabValues) {
  return otherTabValues.size;
}
function useTab(parameters) {
  const {
    value: valueParam,
    rootRef: externalRef,
    disabled = false,
    id: idParam
  } = parameters;
  const tabRef = React.useRef(null);
  const id = (0, _useId.useId)(idParam);
  const {
    value: selectedValue,
    getTabPanelId,
    orientation
  } = (0, _TabsContext.useTabsContext)();
  const tabMetadata = React.useMemo(() => ({
    disabled,
    ref: tabRef,
    id
  }), [disabled, tabRef, id]);
  const {
    id: value,
    index,
    totalItemCount: totalTabsCount
  } = (0, _useCompound.useCompoundItem)(valueParam ?? tabValueGenerator, tabMetadata);
  const {
    getRootProps: getListItemProps,
    selected
  } = (0, _useList.useListItem)({
    item: value
  });
  const {
    getButtonProps,
    buttonRef: buttonRefHandler
  } = (0, _useButton.useButton)({
    disabled,
    focusableWhenDisabled: true,
    type: 'button'
  });
  const handleRef = (0, _useForkRef.useForkRef)(tabRef, externalRef, buttonRefHandler);
  const tabPanelId = value !== undefined ? getTabPanelId(value) : undefined;
  const getRootProps = React.useCallback((externalProps = {}) => {
    //
    return (0, _mergeReactProps.mergeReactProps)(externalProps, (0, _mergeReactProps.mergeReactProps)({
      role: 'tab',
      'aria-controls': tabPanelId,
      'aria-selected': selected,
      id,
      ref: handleRef
    }, (0, _mergeReactProps.mergeReactProps)(getListItemProps(), getButtonProps())));
  }, [getButtonProps, getListItemProps, handleRef, id, selected, tabPanelId]);
  return {
    getRootProps,
    index,
    rootRef: handleRef,
    // the `selected` state isn't set on the server (it relies on effects to be calculated),
    // so we fall back to checking the `value` prop with the selectedValue from the TabsContext
    selected: selected || value === selectedValue,
    totalTabsCount,
    orientation
  };
}