"use strict";
'use client';

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TooltipRoot = TooltipRoot;
var React = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _TooltipRootContext = require("./TooltipRootContext");
var _useTooltipRoot = require("./useTooltipRoot");
var _constants = require("../utils/constants");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * The foundation for building custom-styled tooltips.
 *
 * Demos:
 *
 * - [Tooltip](https://base-ui.netlify.app/components/react-tooltip/)
 *
 * API:
 *
 * - [TooltipRoot API](https://base-ui.netlify.app/components/react-tooltip/#api-reference-TooltipRoot)
 */function TooltipRoot(props) {
  const {
    delayType = 'rest',
    delay,
    closeDelay,
    hoverable = true,
    animated = true,
    trackCursorAxis = 'none'
  } = props;
  const delayWithDefault = delay ?? _constants.OPEN_DELAY;
  const closeDelayWithDefault = closeDelay ?? 0;
  const {
    open,
    setOpen,
    mounted,
    setMounted,
    triggerElement,
    setTriggerElement,
    positionerElement,
    setPositionerElement,
    popupRef,
    instantType,
    getRootTriggerProps,
    getRootPopupProps,
    floatingRootContext,
    transitionStatus
  } = (0, _useTooltipRoot.useTooltipRoot)({
    hoverable,
    animated,
    trackCursorAxis,
    delay,
    delayType,
    closeDelay,
    open: props.open,
    onOpenChange: props.onOpenChange,
    defaultOpen: props.defaultOpen
  });
  const contextValue = React.useMemo(() => ({
    delay: delayWithDefault,
    delayType,
    closeDelay: closeDelayWithDefault,
    open,
    setOpen,
    triggerElement,
    setTriggerElement,
    positionerElement,
    setPositionerElement,
    popupRef,
    mounted,
    setMounted,
    instantType,
    getRootTriggerProps,
    getRootPopupProps,
    floatingRootContext,
    trackCursorAxis,
    transitionStatus
  }), [delayWithDefault, delayType, closeDelayWithDefault, open, setOpen, triggerElement, setTriggerElement, positionerElement, setPositionerElement, popupRef, mounted, setMounted, instantType, getRootTriggerProps, getRootPopupProps, floatingRootContext, trackCursorAxis, transitionStatus]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipRootContext.TooltipRootContext.Provider, {
    value: contextValue,
    children: props.children
  });
}
process.env.NODE_ENV !== "production" ? TooltipRoot.propTypes /* remove-proptypes */ = {
  // ┌────────────────────────────── Warning ──────────────────────────────┐
  // │ These PropTypes are generated from the TypeScript type definitions. │
  // │ To update them, edit the TypeScript types and run `pnpm proptypes`. │
  // └─────────────────────────────────────────────────────────────────────┘
  /**
   * Whether the tooltip can animate, adding animation-related attributes and allowing for exit
   * animations to play. Useful to disable in tests to remove async behavior.
   * @default true
   */
  animated: _propTypes.default.bool,
  /**
   * @ignore
   */
  children: _propTypes.default.node,
  /**
   * The delay in milliseconds until the tooltip popup is closed.
   * @default 0
   */
  closeDelay: _propTypes.default.number,
  /**
   * Whether the tooltip popup is open by default. Use when uncontrolled.
   * @default false
   */
  defaultOpen: _propTypes.default.bool,
  /**
   * The delay in milliseconds until the tooltip popup is opened.
   * @default 600
   */
  delay: _propTypes.default.number,
  /**
   * The delay type to use. `rest` means the `delay` represents how long the user's cursor must
   * rest on the trigger before the tooltip popup is opened. `hover` means the `delay` represents
   * how long to wait as soon as the user's cursor has entered the trigger.
   * @default 'rest'
   */
  delayType: _propTypes.default.oneOf(['hover', 'rest']),
  /**
   * Whether the user can move their cursor from the trigger element toward the tooltip popup element
   * without it closing using a "safe polygon" technique.
   * @default true
   */
  hoverable: _propTypes.default.bool,
  /**
   * Callback fired when the tooltip popup is requested to be opened or closed. Use when controlled.
   */
  onOpenChange: _propTypes.default.func,
  /**
   * Whether the tooltip popup is open. Use when controlled.
   * @default false
   */
  open: _propTypes.default.bool,
  /**
   * Determines which axis the tooltip should track the cursor on.
   * @default 'none'
   */
  trackCursorAxis: _propTypes.default.oneOf(['both', 'none', 'x', 'y'])
} : void 0;