"use strict";
'use client';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAnimationsFinished = useAnimationsFinished;
var React = _interopRequireWildcard(require("react"));
var _useEventCallback = require("./useEventCallback");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Executes a function once all animations have finished on the provided element.
 * @ignore - internal hook.
 */
function useAnimationsFinished(ref) {
  const frameRef = React.useRef(-1);
  const cancelFrames = (0, _useEventCallback.useEventCallback)(() => {
    cancelAnimationFrame(frameRef.current);
  });
  React.useEffect(() => cancelFrames, [cancelFrames]);
  return (0, _useEventCallback.useEventCallback)(fnToExecute => {
    cancelFrames();
    const element = ref.current;
    if (!element) {
      return;
    }

    // Wait for the CSS styles to be applied to determine if the animation has been removed in the
    // [data-instant] state. This allows the close animation to play if the `delay` instantType is
    // applying to the same element.
    frameRef.current = requestAnimationFrame(async () => {
      await Promise.allSettled(element.getAnimations().map(animation => animation.finished));
      fnToExecute();
    });
  });
}