"use strict";
'use client';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTransitionStatus = useTransitionStatus;
var React = _interopRequireWildcard(require("react"));
var _useEnhancedEffect = require("./useEnhancedEffect");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Provides a status string for CSS animations.
 * @param open - a boolean that determines if the element is open.
 * @param enabled - a boolean that determines if the logic is enabled.
 * @ignore - internal hook.
 */
function useTransitionStatus(open, enabled = true) {
  const [transitionStatus, setTransitionStatus] = React.useState();
  const [mounted, setMounted] = React.useState(open);
  const derivedMounted = enabled ? mounted : open;
  if (enabled) {
    if (open && !mounted) {
      setMounted(true);
    }
    if (!open && mounted && transitionStatus !== 'exiting') {
      setTransitionStatus('exiting');
    }
    if (!open && !mounted && transitionStatus === 'exiting') {
      setTransitionStatus(undefined);
    }
  }
  (0, _useEnhancedEffect.useEnhancedEffect)(() => {
    if (!enabled || !open) {
      return undefined;
    }
    setTransitionStatus('entering');
    const frame = requestAnimationFrame(() => {
      setTransitionStatus(undefined);
    });
    return () => {
      cancelAnimationFrame(frame);
    };
  }, [enabled, open]);
  return React.useMemo(() => ({
    mounted: derivedMounted,
    setMounted,
    transitionStatus
  }), [derivedMounted, transitionStatus]);
}